// ******************************************************************************/
// * @file     gpio.c
// * @brief    
// *           
// * @version  V1.01
// * @date     19. January 2021
// ******************************************************************************/
#include "gpio_def.h"
#include "eKTF7020.h"

#define GPIO_BITMASK_MODER             	0x00000003U
#define GPIO_BITMASK_OUTEN	  		  		0x00000001U
#define GPIO_BITMASK_OTYPER							0x00000003U
#define GPIO_BITMASK_PUR								0x00000003U
#define GPIO_BITMASK_PDR								0x00000003U
#define GPIO_BITMASK_HDHSR							0x00000001U
#define GPIO_BITMASK_IHYSTER						0x00000001U
#define GPIO_BITMASK_AF									0x0000000FU
#define GPIO_NUMBER           					16U

void GPIO_Init(GPIO_IPTypeDef* GPIOIPx, GPIO_TypeDef* GPIOx, GPIO_InitTypeDef *GPIO_Init){
		uint32_t position;
		uint32_t position2;
		uint32_t ioposition = 0x00U;
		uint32_t iocurrent = 0x00U;
		uint32_t temp = 0x00U;

		/* Configure the port pins */
		for(position = 0U; position < GPIO_NUMBER; position++){
			/* Get the IO position */
			ioposition = 0x01U << position;
			/* Get the current IO position */
			iocurrent = (uint32_t)(GPIO_Init->Pin) & ioposition;

			if(iocurrent == ioposition){		
	
				/*--------------------- GPIO Mode Configuration ------------------------*/				
				temp = GPIOx->MODER; 																									// Load MODER data to temp				
				temp &= ~(GPIO_MODER_MODER0 << (position * 2U));											// Clear MODER by position
				temp |= ((GPIO_Init->Mode & GPIO_BITMASK_MODER) << (position * 2U));	// Set MODER by position
				GPIOx->MODER = temp;																									// Write MODER data to SFR				
	
				/*--------------------- GPIO input/output Configuration ------------------------*/					
				if(GPIO_Init->Mode == GPIOx_MODER_DG_IO){			
					if(GPIO_Init->OutputEnable == GPIOx_OUTEN_EN){		
						temp = 0U;
						temp &= ~(GPIO_OUTENSET_OUTENSET0 << (position));							
						temp |= ((GPIO_Init->OutputEnable & GPIO_BITMASK_OUTEN) << (position ));	
						GPIOIPx->OUTENSET = (uint16_t)temp;
					}
					else{			
						temp = 0U;						
						temp &= ~(GPIO_OUTENCLR_OUTENCLR0 << (position));							
						temp |= ((~(GPIO_Init->OutputEnable) & GPIO_BITMASK_OUTEN) << (position ));	
						GPIOIPx->OUTENCLR = (uint16_t)temp;						
					}	
				}

				/*--------------------- GPIO PP/OD/OS Configuration ------------------------*/						
				if((GPIO_Init->Mode == GPIOx_MODER_DG_IO) && (GPIO_Init->OutputEnable == GPIOx_OUTEN_EN)){				
					temp = GPIOx->OTYPER;						
					temp &= ~(GPIO_OTYPER_OTYPER0 << (position * 2U));							
					temp |= ((GPIO_Init->OutputType & GPIO_BITMASK_OTYPER) << (position * 2U ));	
					GPIOx->OTYPER = temp;						
				}
	
				/*--------------------- GPIO Pull-up/Pull-down Configuration ------------------------*/					
				if((GPIO_Init->Mode == GPIOx_MODER_DG_IO) || (GPIO_Init->Mode == GPIOx_MODER_DG_AF) ){
					/* Activate the Pull-up resistor for the current IO */	
					temp = GPIOx->PUR; 					
					temp &= ~(GPIO_PUR_PUR0 << (position * 2U));							
					temp |= ((GPIO_Init->PullUp & GPIO_BITMASK_PUR) << (position * 2U ));					
					GPIOx->PUR = temp;		

					/* Activate the Pull-down resistor for the current IO */
					temp = GPIOx->PDR;						
					temp &= ~(GPIO_PDR_PDR0 << (position * 2U));							
					temp |= ((GPIO_Init->PullDown & GPIO_BITMASK_PDR) << (position * 2U ));					
					GPIOx->PDR = temp;						
				}			

				/*--------------------- GPIO high drive and high sink Configuration -----------------*/			
				if(((GPIO_Init->Mode == GPIOx_MODER_DG_IO) && (GPIO_Init->OutputEnable == GPIOx_OUTEN_EN)) || (GPIO_Init->Mode == GPIOx_MODER_DG_AF)){					
					temp = GPIOx->HDHSR; 							
					temp &= ~(GPIO_HDHSR_HDHSR0 << (position));							
					temp |= ((GPIO_Init->HighDriveSink & GPIO_BITMASK_HDHSR) << (position ));	
					GPIOx->HDHSR = temp;						
				}				
				
				if((GPIO_Init->Mode == GPIOx_MODER_DG_IO) || (GPIO_Init->Mode == GPIOx_MODER_DG_AF)){					
					/*--------------------- GPIO input hysteresis enable/disable Configuration ----------*/					
					temp = GPIOx->IHYSTER;		
					temp &= ~(GPIO_IHYSTER_IHYSTER0 << (position));							
					temp |= ((GPIO_Init->InputHysteresis & GPIO_BITMASK_IHYSTER) << (position ));	
					GPIOx->IHYSTER = temp;	
				}					
				
				/* In case of Digital Alternate function mode selection */
				if(GPIO_Init->Mode == GPIOx_MODER_DG_AF){
					if(position < 8U)
					{
						temp = GPIOx->DG_AFSELRL;					
						temp &= ~(GPIO_DG_AFSELRL_DG_AFSELRL0 << (position * 4U));							
						temp |= ((GPIO_Init->Alternate & GPIO_BITMASK_AF) << (position * 4U));
						GPIOx->DG_AFSELRL = temp;		
					}
					else
					{
						position2 = (position - 8U);
						temp = GPIOx->DG_AFSELRH;					
						temp &= ~(GPIO_DG_AFSELRL_DG_AFSELRL0 << (position2 * 4U));							
						temp |= ((GPIO_Init->Alternate & GPIO_BITMASK_AF) << (position2 * 4U));
						GPIOx->DG_AFSELRH = temp;
					}						
				}

				/* In case of Analog Alternate function mode selection */
				if(GPIO_Init->Mode == GPIOx_MODER_ANL_AF){
					temp = GPIOx->ANL_AFSELR;								
					temp &= ~(GPIO_ANL_AFSELR_ANL_AFSELR0 << (position * 2U));							
					temp |= ((GPIO_Init->Alternate & GPIO_BITMASK_AF) << (position * 2U));	
					GPIOx->ANL_AFSELR = temp;																												
				}
			}
		}
}


GPIO_PinState GPIO_ReadPin(GPIO_IPTypeDef* GPIOIPx, uint16_t GPIO_Pin){
		GPIO_PinState bitstatus;

		if((GPIOIPx->DATA & GPIO_Pin) != (uint16_t)GPIO_PIN_RESET){
			bitstatus = GPIO_PIN_SET;
		}
		else{
			bitstatus = GPIO_PIN_RESET;
		}
		return bitstatus;
}

uint32_t GPIO_ReadPort(GPIO_IPTypeDef* GPIOIPx){
	    return GPIOIPx->DATA;
}

void GPIO_WritePin(GPIO_IPTypeDef* GPIOIPx, uint16_t GPIO_Pin, GPIO_PinState PinValue){	
		if(PinValue != GPIO_PIN_RESET){
			GPIOIPx->DATAOUT |= GPIO_Pin;
		}
		else{
			GPIOIPx->DATAOUT &= ~GPIO_Pin;
		}
}

void GPIO_WritePort(GPIO_IPTypeDef* GPIOIPx, uint16_t PortValue){
    GPIOIPx->DATAOUT = PortValue;
}

void GPIO_TogglePin(GPIO_IPTypeDef* GPIOIPx, uint16_t GPIO_Pin){
    if((GPIOIPx->DATAOUT & GPIO_Pin) != (uint16_t)GPIO_PIN_RESET){
			GPIOIPx->DATAOUT &= ~GPIO_Pin;
    }
    else{
      GPIOIPx->DATAOUT |= GPIO_Pin;
    }	
}

void MX_GPIO_Init(void){
  GPIO_InitTypeDef GPIO_InitStruct;  
	
	/*	P5~P0 is input*/	
  GPIO_InitStruct.Pin = 	GPIO_PIN_0|GPIO_PIN_1|GPIO_PIN_2|GPIO_PIN_3|GPIO_PIN_4|GPIO_PIN_5|GPIO_PIN_6|GPIO_PIN_7|GPIO_PIN_8
												  |GPIO_PIN_9|GPIO_PIN_10|GPIO_PIN_11|GPIO_PIN_12|GPIO_PIN_13|GPIO_PIN_14|GPIO_PIN_15;
	GPIO_InitStruct.Mode = GPIOx_MODER_DG_IO;	
	GPIO_InitStruct.OutputEnable = GPIOx_OUTEN_DIS;
	GPIO_InitStruct.OutputType = 	GPIOx_OTYPER_PP;			
	GPIO_InitStruct.PullUp = GPIOx_PUR_DIS;	
	GPIO_InitStruct.PullDown = GPIOx_PDR_DIS;		
	GPIO_InitStruct.HighDriveSink = GPIOx_HDHSR_NORMAL;	
	GPIO_InitStruct.InputHysteresis = GPIOx_IHYSTER_EN;	
  GPIO_Init(GPIOIPA, GPIOA, &GPIO_InitStruct);		
  GPIO_Init(GPIOIPB, GPIOB, &GPIO_InitStruct);		
  GPIO_Init(GPIOIPC, GPIOC, &GPIO_InitStruct);	
	
	/* GPIOC initial	*/
	/*	PC5 default is the RESET pin and in pull-up 0 */
  GPIO_InitStruct.Pin = 	GPIOC_RESET_PIN_05;
  GPIO_InitStruct.Mode = GPIOx_MODER_DG_AF;	
	GPIO_InitStruct.OutputEnable = GPIOx_OUTEN_DIS;
  GPIO_InitStruct.PullUp = GPIOx_PUR_PU0;	
	GPIO_InitStruct.PullDown = GPIOx_PDR_DIS;	
	GPIO_InitStruct.HighDriveSink = GPIOx_HDHSR_NORMAL;
  GPIO_InitStruct.Alternate = GPIOx_DG_AFSEL_RESET;	
	GPIO_InitStruct.InputHysteresis = GPIOx_IHYSTER_EN;	
  GPIO_Init(GPIOIPC, GPIOC, &GPIO_InitStruct);	
		
	/* GPIOC initial	*/
	/*	PC4 default is the SWCLK pin and in pull-up 0 */
  GPIO_InitStruct.Pin = 	GPIOC_SWCLK_PIN_04;
  GPIO_InitStruct.Mode = GPIOx_MODER_DG_AF;	
	GPIO_InitStruct.OutputEnable = GPIOx_OUTEN_DIS;
  GPIO_InitStruct.PullUp = GPIOx_PUR_PU0;	
	GPIO_InitStruct.PullDown = GPIOx_PDR_DIS;	
	GPIO_InitStruct.HighDriveSink = GPIOx_HDHSR_NORMAL;
  GPIO_InitStruct.Alternate = GPIOx_DG_AFSEL_SWD;	
	GPIO_InitStruct.InputHysteresis = GPIOx_IHYSTER_EN;	
  GPIO_Init(GPIOIPC, GPIOC, &GPIO_InitStruct);	

	/*	PC3 default is the SWDIO pin and SWDIO in pull-down 0 */
	GPIO_InitStruct.Pin = 	GPIOC_SWDIO_PIN_03;
  GPIO_InitStruct.Mode = GPIOx_MODER_DG_AF;	
	GPIO_InitStruct.OutputEnable = GPIOx_OUTEN_DIS;
  GPIO_InitStruct.PullUp = GPIOx_PUR_DIS;	
	GPIO_InitStruct.PullDown = GPIOx_PDR_PD0;	
	GPIO_InitStruct.HighDriveSink = GPIOx_HDHSR_NORMAL;
  GPIO_InitStruct.Alternate = GPIOx_DG_AFSEL_SWD;	
	GPIO_InitStruct.InputHysteresis = GPIOx_IHYSTER_EN;	
  GPIO_Init(GPIOIPC, GPIOC, &GPIO_InitStruct);		
}



