/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef _GPIO_H
#define _GPIO_H

/* Includes ------------------------------------------------------------------*/
#include <stdint.h>
#include "CMSDK_CM0plus.h"

/*!<	GPIO registers structures ----------------------------------------------*/
typedef struct
{
  __IO uint32_t MODER;    		/*!< GPIO port mode register,               						Address offset: 0x00      */
	__IO uint32_t DG_AFSELRL;   /*!< GPIO alternate function low registers,        			Address offset: 0x04      */	
  __IO uint32_t DG_AFSELRH;  	/*!< GPIO alternate function high registers,       			Address offset: 0x08      */	
  __IO uint32_t ANL_AFSELR;   /*!< GPIO port pull-up/pull-down register,  						Address offset: 0x0C      */		
  __IO uint32_t OTYPER;      	/*!< GPIO port PP/OD/OS selection register,         		Address offset: 0x10      */
  __IO uint32_t PUR;      		/*!< GPIO pull-up register,        											Address offset: 0x14      */
  __IO uint32_t PDR;     			/*!< GPIO pull-down register,      											Address offset: 0x18      */
  __IO uint32_t HDHSR;     		/*!< GPIO port high driver and sink register, 					Address offset: 0x1C      */
  __IO uint32_t IHYSTER;   		/*!< Configure the GPIO input hysteresis registers,     Address offset: 0x20 			*/
} GPIO_TypeDef;
#define GPIOA               ((GPIO_TypeDef *) GPIOCFGA_BASE)
#define GPIOB               ((GPIO_TypeDef *) GPIOCFGB_BASE)
#define GPIOC               ((GPIO_TypeDef *) GPIOCFGC_BASE)

typedef struct
{
	__IO uint16_t DATA;             // 0x00
	__IO uint16_t dummy0;
	__IO uint16_t DATAOUT;          // 0x04
	__IO uint16_t dummy1;
	__IO uint16_t Reserved0;
	__IO uint16_t dummy2;
	__IO uint16_t Reserved1;
	__IO uint16_t dummy3;
	__IO uint16_t OUTENSET;       	// 0x10
	__IO uint16_t dummy4;
	__IO uint16_t OUTENCLR;       	// 0x14
	__IO uint16_t dummy5;
	__IO uint16_t Reserved2;       	// 0x18
	__IO uint16_t dummy6;
	__IO uint16_t Reserved3;       	// 0x1c
	__IO uint16_t dummy7;
	__IO uint16_t INTENSET;         // 0x20
	__IO uint16_t dummy8;
	__IO uint16_t INTENCLR;         // 0x24
	__IO uint16_t dummy9;
	__IO uint16_t INTTYPESET;   		// 0x28
	__IO uint16_t dummy10;
	__IO uint16_t INTTYPECLR;   		// 0x2c
	__IO uint16_t dummy11;
	__IO uint16_t INTPOLSET;        // 0x30
	__IO uint16_t dummy12;
	__IO uint16_t INTPOLCLR;        // 0x34
	__IO uint16_t dummy13;
	__IO uint16_t INTSR_INTCLR;  		// 0x38
	__IO uint16_t dummy14;
}GPIO_IPTypeDef;	 
#define GPIOIPA 						((GPIO_IPTypeDef *) GPIOIPA_BASE)
#define GPIOIPB 						((GPIO_IPTypeDef *) GPIOIPB_BASE)
#define GPIOIPC 						((GPIO_IPTypeDef *) GPIOIPC_BASE)	  

typedef struct
{
	uint32_t	Pin;
	uint32_t	Mode;
	uint32_t	OutputEnable;				// Configure the I/O is input or output		
	uint32_t	OutputType;					// Configure the I/O is PP/OD/OS output	
	uint32_t	PullUp;	
	uint32_t	PullDown;
	uint32_t	HighDriveSink;
	uint32_t	InputHysteresis;		// Configure the I/O input hysteresis.
	uint32_t	Alternate;	
}GPIO_InitTypeDef;
 
/*!<	GPIO Bit SET and Bit RESET enumeration	*/
typedef enum
{
  GPIO_PIN_RESET = 0,
  GPIO_PIN_SET
}GPIO_PinState;

/*!<	GPIO pins define	*/
#define GPIO_PIN_0                 ((uint16_t)0x0001)  /* Pin 0 selected    */
#define GPIO_PIN_1                 ((uint16_t)0x0002)  /* Pin 1 selected    */
#define GPIO_PIN_2                 ((uint16_t)0x0004)  /* Pin 2 selected    */
#define GPIO_PIN_3                 ((uint16_t)0x0008)  /* Pin 3 selected    */
#define GPIO_PIN_4                 ((uint16_t)0x0010)  /* Pin 4 selected    */
#define GPIO_PIN_5                 ((uint16_t)0x0020)  /* Pin 5 selected    */
#define GPIO_PIN_6                 ((uint16_t)0x0040)  /* Pin 6 selected    */
#define GPIO_PIN_7                 ((uint16_t)0x0080)  /* Pin 7 selected    */
#define GPIO_PIN_8                 ((uint16_t)0x0100)  /* Pin 8 selected    */
#define GPIO_PIN_9                 ((uint16_t)0x0200)  /* Pin 9 selected    */
#define GPIO_PIN_10                ((uint16_t)0x0400)  /* Pin 10 selected   */
#define GPIO_PIN_11                ((uint16_t)0x0800)  /* Pin 11 selected   */
#define GPIO_PIN_12                ((uint16_t)0x1000)  /* Pin 12 selected   */
#define GPIO_PIN_13                ((uint16_t)0x2000)  /* Pin 13 selected   */
#define GPIO_PIN_14                ((uint16_t)0x4000)  /* Pin 14 selected   */
#define GPIO_PIN_15                ((uint16_t)0x8000)  /* Pin 15 selected   */
#define GPIO_PIN_All               ((uint16_t)0xFFFF)  /* All pins selected */

#define GPIO_PIN_MASK              0x0000FFFFU /* PIN mask for assert test */

#define	GPIOx_MODER_DG_IO						0x00000000U
#define	GPIOx_MODER_DG_AF						0x00000001U
#define	GPIOx_MODER_ANL_AF					0x00000002U

#define	GPIOx_OUTEN_DIS							0x00000000U
#define	GPIOx_OUTEN_EN							0x00000001U

#define	GPIOx_OTYPER_PP							0x00000000U
#define	GPIOx_OTYPER_OD							0x00000001U
#define	GPIOx_OTYPER_OS							0x00000002U

#define	GPIOx_PUR_DIS								0x00000000U
#define	GPIOx_PUR_PU0								0x00000001U
#define	GPIOx_PUR_PU1								0x00000002U

#define	GPIOx_PDR_DIS								0x00000000U
#define	GPIOx_PDR_PD0								0x00000001U
#define	GPIOx_PDR_PD1								0x00000002U

#define	GPIOx_HDHSR_NORMAL					0x00000000U
#define	GPIOx_HDHSR_HIGH						0x00000001U

#define	GPIOx_IHYSTER_DIS						0x00000000U
#define	GPIOx_IHYSTER_EN						0x00000001U

/*!<	Alternate registers define	*/
#define	GPIOx_DG_AFSEL_EXTIN_FA							0x00000000U		/*	DG_AF0	*/
#define	GPIOx_DG_AFSEL_TC										0x00000000U		/*	DG_AF0	*/
#define	GPIOx_DG_AFSEL_RESET								0x00000000U		/*	DG_AF0	*/
#define	GPIOx_DG_AFSEL_PWM									0x00000000U		/*	DG_AF0	*/
#define	GPIOx_DG_AFSEL_SWD									0x00000000U		/*	DG_AF0	*/
#define	GPIOx_DG_AFSEL_CKO									0x00000000U		/*	DG_AF0	*/
#define	GPIOx_DG_AFSEL_I2C									0x00000001U		/*	DG_AF1	*/
#define	GPIOx_DG_AFSEL_UART									0x00000002U		/*	DG_AF2	*/
#define	GPIOx_DG_AFSEL_USART								0x00000003U		/*	DG_AF3	*/
#define	GPIOx_DG_AFSEL_INT									0x00000004U		/*	DG_AF4	*/
#define	GPIOx_ANL_AFSEL_TK									0x00000000U		/*	ANL_AF0	*/
#define	GPIOx_ANL_AFSEL_TKD									0x00000001U		/*	ANL_AF0	*/

/*!<	Alternate pin define	*/
/*!	DG_AF0	*/
#define	GPIOA_EXTIN_FA_PIN_00								0x0001U				/*	0000_0000_0000_0001	*/
#define	GPIOA_TC1_PIN_01										0x0002U				/*	0000_0000_0000_0010	*/
#define	GPIOA_TC2_PIN_03										0x0008U				/*	0000_0000_0000_1000	*/
#define	GPIOB_CLKO2_PIN_01									0x0002U				/*	0000_0000_0000_0010	*/
#define	GPIOB_PWM1_PIN_12										0x1000U				/*	0001_0000_0000_0000	*/
#define	GPIOB_PWM2_PIN_13										0x2000U				/*	0010_0000_0000_0000	*/
#define	GPIOB_PWM3_PIN_14										0x4000U				/*	0100_0000_0000_0000	*/
#define	GPIOC_CLKO1_PIN_00									0x0001U				/*	0000_0000_0000_0001	*/
#define	GPIOC_SWDIO_PIN_03									0x0008U				/*	0000_0000_0000_1000	*/
#define	GPIOC_SWCLK_PIN_04									0x0010U				/*	0000_0000_0001_0000	*/
#define	GPIOC_RESET_PIN_05									0x0020U				/*	0000_0000_0010_0000	*/
/*!	DG_AF1	*/
#define	GPIOC_SDA0_PIN_01										0x0002U				/*	0000_0000_0000_0010	*/
#define	GPIOC_SCL0_PIN_02										0x0004U				/*	0000_0000_0000_0100	*/
#define	GPIOC_SDA1_PIN_03										0x0008U				/*	0000_0000_0000_1000	*/
#define	GPIOC_SCL1_PIN_04										0x0010U				/*	0000_0000_0001_0000	*/
/*!	DG_AF2	*/
#define	GPIOC_TX0_PIN_01										0x0002U				/*	0000_0000_0000_0010	*/
#define	GPIOC_TR0_PIN_02										0x0004U				/*	0000_0000_0000_0100	*/
#define	GPIOC_TX1_PIN_03										0x0008U				/*	0000_0000_0000_1000	*/
#define	GPIOC_TR1_PIN_04										0x0010U				/*	0000_0000_0001_0000	*/
/*!	DG_AF3	*/
#define	GPIOC_USART_CK_PIN_00								0x0001U				/*	0000_0000_0000_0001	*/
#define	GPIOC_USART_TX_PIN_01								0x0002U				/*	0000_0000_0000_0010	*/
#define	GPIOC_USART_RX_PIN_02								0x0004U				/*	0000_0000_0000_0100	*/
/*!	DG_AF4	*/
#define	GPIOA_INT1_PIN_00										0x0001U				/*	0000_0000_0000_0001	*/
#define	GPIOA_INT2_PIN_04										0x0010U				/*	0000_0000_0001_0000	*/
#define	GPIOB_INT3_PIN_00										0x0001U				/*	0000_0000_0000_0001	*/
#define	GPIOB_INT4_PIN_04										0x0010U				/*	0000_0000_0001_0000	*/
#define	GPIOB_INT5_PIN_08										0x0100U				/*	0000_0001_0000_0000	*/
#define	GPIOB_INT6_PIN_12										0x1000U				/*	0001_0000_0000_0000	*/
#define	GPIOC_INT0_PIN_00										0x0001U				/*	0000_0000_0000_0001	*/
#define	GPIOC_INT7_PIN_02										0x0004U				/*	0000_0000_0000_0100	*/

/*!<	GPIO initialization functions ********************************************/
void GPIO_Init(GPIO_IPTypeDef* GPIOIPx, GPIO_TypeDef* GPIOx, GPIO_InitTypeDef* GPIO_Init);

/*!<	GPIO base functions ***************************************************/
GPIO_PinState GPIO_ReadPin(GPIO_IPTypeDef* GPIOIPx, uint16_t GPIO_Pin);
uint32_t GPIO_ReadPort(GPIO_IPTypeDef* GPIOIPx);
void GPIO_WritePin(GPIO_IPTypeDef* GPIOIPx, uint16_t GPIO_Pin, GPIO_PinState PinValue);
void GPIO_WritePort(GPIO_IPTypeDef* GPIOIPx, uint16_t PortValue);
void GPIO_TogglePin(GPIO_IPTypeDef* GPIOIPx, uint16_t GPIO_Pin);

/*!<	GPIO operation functions ***************************************************/
void MX_GPIO_Init(void);	

#endif 

