
#ifndef _eKTF7020_H
#define _eKTF7020_H

/* Includes ------------------------------------------------------------------*/
#include <stdint.h>
#include "CMSDK_CM0plus.h"

/******************************************************************************/
/*                                                                            */
/*                            Memory Map                             					*/
/*                                                                            */
/******************************************************************************/
/*!< Memory_map	*/
#define FLASH_MAIN_BASE       ((uint32_t)0x10000000) /*!< Flash main area(20KB) base address in the alias region                 */
#define FLAS_BOOT_BASE				((uint32_t)0x10005000) /*!< Boot area(2KB) base address in the alias region                        */
#define IDRAM_BASE            ((uint32_t)0x20000000) /*!< IDRAM(4KB) base address in the alias region                            */
#define PERIPH_BASE           ((uint32_t)0x40000000) /*!< Peripheral base address in the alias region                            */

/*!< Legacy defines */
#define SRAM_BASE             IDRAM_BASE

/*!< Peripheral memory map */
#define APB1PERIPH_BASE       PERIPH_BASE
#define AHB1PERIPH_BASE       (PERIPH_BASE + 0x00020000)
#define APB3PERIPH_BASE       (PERIPH_BASE + 0x00030000)

/*!< APB1 peripherals */
#define TIMER1_BASE           (APB1PERIPH_BASE + 0x0000)
#define TIMER2_BASE           (APB1PERIPH_BASE + 0x1000)
#define UART_BASE            	(APB1PERIPH_BASE + 0x2000)
#define SPI_BASE              (APB1PERIPH_BASE + 0x3000)
#define I2C_BASE              (APB1PERIPH_BASE + 0x4000)
#define PWM_BASE            	(APB1PERIPH_BASE + 0x6000)
#define USART_BASE            (APB1PERIPH_BASE + 0x8000)
#define EINT_BASE             (APB1PERIPH_BASE + 0x9000)
#define TK_BASE               (APB1PERIPH_BASE + 0xE000)

/*!< APB3 peripherals */
#define SYSCFG_BASE           (APB3PERIPH_BASE + 0x0000)
#define CLKCFG_BASE           (APB3PERIPH_BASE + 0x0100)
#define RSTREG_BASE       		(APB3PERIPH_BASE + 0x0200)
#define GPIOCFG_BASE          (APB3PERIPH_BASE + 0x1000)
#define GPIOCFGA_BASE         GPIOCFG_BASE
#define GPIOCFGB_BASE         (GPIOCFG_BASE + 0x0100)
#define GPIOCFGC_BASE         (GPIOCFG_BASE + 0x0200)
#define FLASHCTRL_BASE        (APB3PERIPH_BASE + 0x4000)
#define IWDG_BASE             (APB3PERIPH_BASE + 0x5000)
#define AIP_BASE              (APB3PERIPH_BASE + 0x6000)

/*!< AHB1 peripherals */
#define GPIOIPA_BASE          (AHB1PERIPH_BASE + 0x0000)
#define GPIOIPB_BASE          (AHB1PERIPH_BASE + 0x1000)
#define GPIOIPC_BASE          (AHB1PERIPH_BASE + 0x2000)

/*!< SYSCFG */
#define CLKCTRL_BASE          (SYSCFG_BASE + 0x0000)
#define RSTCTRL_BASE          (SYSCFG_BASE + 0x0200)
#define MCUDBG_BASE          	(SYSCFG_BASE + 0x0300)

/*!< Memory protect */
#define MEMPROTECT_BASE       (FLASHCTRL_BASE + 0x0030)

/*!< PWM */
#define PWM1_BASE             (PWM_BASE + 0x0100)
#define PWM2_BASE             (PWM_BASE + 0x0200)
#define PWM3_BASE             (PWM_BASE + 0x0300)

/*!< TK_Group */
#define TK_Group1_BASE             (TK_BASE + 0x0100)
#define TK_Group2_BASE             (TK_BASE + 0x0200)
#define TK_Group3_BASE             (TK_BASE + 0x0300)
#define TK_Group4_BASE             (TK_BASE + 0x0400)
#define TK_Group5_BASE             (TK_BASE + 0x0500)
#define TK_Group6_BASE             (TK_BASE + 0x0600)

/******************************************************************************/
/*                                                                            */
/*                            General Purpose I/O                             */
/*                                                                            */
/******************************************************************************/
/******************  Bits definition for GPIO_MODER register  *****************/

#define GPIO_MODER_MODER0_Pos            (0U)                                  
#define GPIO_MODER_MODER0_Msk            (0x3U << GPIO_MODER_MODER0_Pos)       /*!< 0x00000003 */
#define GPIO_MODER_MODER0                GPIO_MODER_MODER0_Msk                 
#define GPIO_MODER_MODER1_Pos            (2U)                                  
#define GPIO_MODER_MODER1_Msk            (0x3U << GPIO_MODER_MODER1_Pos)       /*!< 0x0000000C */
#define GPIO_MODER_MODER1                GPIO_MODER_MODER1_Msk                 
#define GPIO_MODER_MODER2_Pos            (4U)                                  
#define GPIO_MODER_MODER2_Msk            (0x3U << GPIO_MODER_MODER2_Pos)       /*!< 0x00000030 */
#define GPIO_MODER_MODER2                GPIO_MODER_MODER2_Msk                 
#define GPIO_MODER_MODER3_Pos            (6U)                                  
#define GPIO_MODER_MODER3_Msk            (0x3U << GPIO_MODER_MODER3_Pos)       /*!< 0x000000C0 */
#define GPIO_MODER_MODER3                GPIO_MODER_MODER3_Msk                 
#define GPIO_MODER_MODER4_Pos            (8U)                                  
#define GPIO_MODER_MODER4_Msk            (0x3U << GPIO_MODER_MODER4_Pos)       /*!< 0x00000300 */
#define GPIO_MODER_MODER4                GPIO_MODER_MODER4_Msk                 
#define GPIO_MODER_MODER5_Pos            (10U)                                 
#define GPIO_MODER_MODER5_Msk            (0x3U << GPIO_MODER_MODER5_Pos)       /*!< 0x00000C00 */
#define GPIO_MODER_MODER5                GPIO_MODER_MODER5_Msk                 
#define GPIO_MODER_MODER6_Pos            (12U)                                 
#define GPIO_MODER_MODER6_Msk            (0x3U << GPIO_MODER_MODER6_Pos)       /*!< 0x00003000 */
#define GPIO_MODER_MODER6                GPIO_MODER_MODER6_Msk                 
#define GPIO_MODER_MODER7_Pos            (14U)                                 
#define GPIO_MODER_MODER7_Msk            (0x3U << GPIO_MODER_MODER7_Pos)       /*!< 0x0000C000 */
#define GPIO_MODER_MODER7                GPIO_MODER_MODER7_Msk                 
#define GPIO_MODER_MODER8_Pos            (16U)                                 
#define GPIO_MODER_MODER8_Msk            (0x3U << GPIO_MODER_MODER8_Pos)       /*!< 0x00030000 */
#define GPIO_MODER_MODER8                GPIO_MODER_MODER8_Msk                 
#define GPIO_MODER_MODER9_Pos            (18U)                                 
#define GPIO_MODER_MODER9_Msk            (0x3U << GPIO_MODER_MODER9_Pos)       /*!< 0x000C0000 */
#define GPIO_MODER_MODER9                GPIO_MODER_MODER9_Msk                 
#define GPIO_MODER_MODER10_Pos           (20U)                                 
#define GPIO_MODER_MODER10_Msk           (0x3U << GPIO_MODER_MODER10_Pos)      /*!< 0x00300000 */
#define GPIO_MODER_MODER10               GPIO_MODER_MODER10_Msk                
#define GPIO_MODER_MODER11_Pos           (22U)                                 
#define GPIO_MODER_MODER11_Msk           (0x3U << GPIO_MODER_MODER11_Pos)      /*!< 0x00C00000 */
#define GPIO_MODER_MODER11               GPIO_MODER_MODER11_Msk                
#define GPIO_MODER_MODER12_Pos           (24U)                                 
#define GPIO_MODER_MODER12_Msk           (0x3U << GPIO_MODER_MODER12_Pos)      /*!< 0x03000000 */
#define GPIO_MODER_MODER12               GPIO_MODER_MODER12_Msk                
#define GPIO_MODER_MODER13_Pos           (26U)                                 
#define GPIO_MODER_MODER13_Msk           (0x3U << GPIO_MODER_MODER13_Pos)      /*!< 0x0C000000 */
#define GPIO_MODER_MODER13               GPIO_MODER_MODER13_Msk                
#define GPIO_MODER_MODER14_Pos           (28U)                                 
#define GPIO_MODER_MODER14_Msk           (0x3U << GPIO_MODER_MODER14_Pos)      /*!< 0x30000000 */
#define GPIO_MODER_MODER14               GPIO_MODER_MODER14_Msk                
#define GPIO_MODER_MODER15_Pos           (30U)                                 
#define GPIO_MODER_MODER15_Msk           (0x3U << GPIO_MODER_MODER15_Pos)      /*!< 0xC0000000 */
#define GPIO_MODER_MODER15               GPIO_MODER_MODER15_Msk                

#define GPIO_DG_AFSELRL_DG_AFSELRL0_Pos            (0U)                                  
#define GPIO_DG_AFSELRL_DG_AFSELRL0_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL0_Pos)       /*!< 0x0000000F */
#define GPIO_DG_AFSELRL_DG_AFSELRL0                GPIO_DG_AFSELRL_DG_AFSELRL0_Msk                 
#define GPIO_DG_AFSELRL_DG_AFSELRL1_Pos            (4U)                                  
#define GPIO_DG_AFSELRL_DG_AFSELRL1_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL1_Pos)       /*!< 0x000000F0 */
#define GPIO_DG_AFSELRL_DG_AFSELRL1                GPIO_DG_AFSELRL_DG_AFSELRL1_Msk                 
#define GPIO_DG_AFSELRL_DG_AFSELRL2_Pos            (8U)                                  
#define GPIO_DG_AFSELRL_DG_AFSELRL2_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL2_Pos)       /*!< 0x00000F00 */
#define GPIO_DG_AFSELRL_DG_AFSELRL2                GPIO_DG_AFSELRL_DG_AFSELRL2_Msk                 
#define GPIO_DG_AFSELRL_DG_AFSELRL3_Pos            (12U)                                  
#define GPIO_DG_AFSELRL_DG_AFSELRL3_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL3_Pos)       /*!< 0x0000F000 */
#define GPIO_DG_AFSELRL_DG_AFSELRL3                GPIO_DG_AFSELRL_DG_AFSELRL3_Msk                 
#define GPIO_DG_AFSELRL_DG_AFSELRL4_Pos            (16U)                                  
#define GPIO_DG_AFSELRL_DG_AFSELRL4_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL4_Pos)       /*!< 0x000F0000 */
#define GPIO_DG_AFSELRL_DG_AFSELRL4                GPIO_DG_AFSELRL_DG_AFSELRL4_Msk                 
#define GPIO_DG_AFSELRL_DG_AFSELRL5_Pos            (20U)                                 
#define GPIO_DG_AFSELRL_DG_AFSELRL5_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL5_Pos)       /*!< 0x00F00000 */
#define GPIO_DG_AFSELRL_DG_AFSELRL5                GPIO_DG_AFSELRL_DG_AFSELRL5_Msk                 
#define GPIO_DG_AFSELRL_DG_AFSELRL6_Pos            (24U)                                 
#define GPIO_DG_AFSELRL_DG_AFSELRL6_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL6_Pos)       /*!< 0x0F000000 */
#define GPIO_DG_AFSELRL_DG_AFSELRL6                GPIO_DG_AFSELRL_DG_AFSELRL6_Msk                 
#define GPIO_DG_AFSELRL_DG_AFSELRL7_Pos            (28U)                                 
#define GPIO_DG_AFSELRL_DG_AFSELRL7_Msk            (0xFU << GPIO_DG_AFSELRL_DG_AFSELRL7_Pos)       /*!< 0xF0000000 */
#define GPIO_DG_AFSELRL_DG_AFSELRL7                GPIO_DG_AFSELRL_DG_AFSELRL7_Msk                 

#define GPIO_DG_AFSELRH_DG_AFSELRH0_Pos            (0U)                                  
#define GPIO_DG_AFSELRH_DG_AFSELRH0_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH0_Pos)       /*!< 0x0000000F */
#define GPIO_DG_AFSELRH_DG_AFSELRH0                GPIO_DG_AFSELRH_DG_AFSELRH0_Msk                 
#define GPIO_DG_AFSELRH_DG_AFSELRH1_Pos            (4U)                                  
#define GPIO_DG_AFSELRH_DG_AFSELRH1_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH1_Pos)       /*!< 0x000000F0 */
#define GPIO_DG_AFSELRH_DG_AFSELRH1                GPIO_DG_AFSELRH_DG_AFSELRH1_Msk                 
#define GPIO_DG_AFSELRH_DG_AFSELRH2_Pos            (8U)                                  
#define GPIO_DG_AFSELRH_DG_AFSELRH2_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH2_Pos)       /*!< 0x00000F00 */
#define GPIO_DG_AFSELRH_DG_AFSELRH2                GPIO_DG_AFSELRH_DG_AFSELRH2_Msk                 
#define GPIO_DG_AFSELRH_DG_AFSELRH3_Pos            (12U)                                  
#define GPIO_DG_AFSELRH_DG_AFSELRH3_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH3_Pos)       /*!< 0x0000F000 */
#define GPIO_DG_AFSELRH_DG_AFSELRH3                GPIO_DG_AFSELRH_DG_AFSELRH3_Msk                 
#define GPIO_DG_AFSELRH_DG_AFSELRH4_Pos            (16U)                                  
#define GPIO_DG_AFSELRH_DG_AFSELRH4_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH4_Pos)       /*!< 0x000F0000 */
#define GPIO_DG_AFSELRH_DG_AFSELRH4                GPIO_DG_AFSELRH_DG_AFSELRH4_Msk                 
#define GPIO_DG_AFSELRH_DG_AFSELRH5_Pos            (20U)                                 
#define GPIO_DG_AFSELRH_DG_AFSELRH5_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH5_Pos)       /*!< 0x00F00000 */
#define GPIO_DG_AFSELRH_DG_AFSELRH5                GPIO_DG_AFSELRH_DG_AFSELRH5_Msk                 
#define GPIO_DG_AFSELRH_DG_AFSELRH6_Pos            (24U)                                 
#define GPIO_DG_AFSELRH_DG_AFSELRH6_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH6_Pos)       /*!< 0x0F000000 */
#define GPIO_DG_AFSELRH_DG_AFSELRH6                GPIO_DG_AFSELRH_DG_AFSELRH6_Msk                 
#define GPIO_DG_AFSELRH_DG_AFSELRH7_Pos            (28U)                                 
#define GPIO_DG_AFSELRH_DG_AFSELRH7_Msk            (0xFU << GPIO_DG_AFSELRH_DG_AFSELRH7_Pos)       /*!< 0xF0000000 */
#define GPIO_DG_AFSELRH_DG_AFSELRH7                GPIO_DG_AFSELRH_DG_AFSELRH7_Msk                 

#define GPIO_ANL_AFSELR_ANL_AFSELR0_Pos            (0U)                                  
#define GPIO_ANL_AFSELR_ANL_AFSELR0_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR0_Pos)       /*!< 0x00000003 */
#define GPIO_ANL_AFSELR_ANL_AFSELR0                GPIO_ANL_AFSELR_ANL_AFSELR0_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR1_Pos            (2U)                                  
#define GPIO_ANL_AFSELR_ANL_AFSELR1_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR1_Pos)       /*!< 0x0000000C */
#define GPIO_ANL_AFSELR_ANL_AFSELR1                GPIO_ANL_AFSELR_ANL_AFSELR1_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR2_Pos            (4U)                                  
#define GPIO_ANL_AFSELR_ANL_AFSELR2_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR2_Pos)       /*!< 0x00000030 */
#define GPIO_ANL_AFSELR_ANL_AFSELR2                GPIO_ANL_AFSELR_ANL_AFSELR2_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR3_Pos            (6U)                                  
#define GPIO_ANL_AFSELR_ANL_AFSELR3_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR3_Pos)       /*!< 0x000000C0 */
#define GPIO_ANL_AFSELR_ANL_AFSELR3                GPIO_ANL_AFSELR_ANL_AFSELR3_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR4_Pos            (8U)                                  
#define GPIO_ANL_AFSELR_ANL_AFSELR4_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR4_Pos)       /*!< 0x00000300 */
#define GPIO_ANL_AFSELR_ANL_AFSELR4                GPIO_ANL_AFSELR_ANL_AFSELR4_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR5_Pos            (10U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR5_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR5_Pos)       /*!< 0x00000C00 */
#define GPIO_ANL_AFSELR_ANL_AFSELR5                GPIO_ANL_AFSELR_ANL_AFSELR5_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR6_Pos            (12U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR6_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR6_Pos)       /*!< 0x00003000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR6                GPIO_ANL_AFSELR_ANL_AFSELR6_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR7_Pos            (14U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR7_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR7_Pos)       /*!< 0x0000C000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR7                GPIO_ANL_AFSELR_ANL_AFSELR7_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR8_Pos            (16U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR8_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR8_Pos)       /*!< 0x00030000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR8                GPIO_ANL_AFSELR_ANL_AFSELR8_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR9_Pos            (18U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR9_Msk            (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR9_Pos)       /*!< 0x000C0000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR9                GPIO_ANL_AFSELR_ANL_AFSELR9_Msk                 
#define GPIO_ANL_AFSELR_ANL_AFSELR10_Pos           (20U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR10_Msk           (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR10_Pos)      /*!< 0x00300000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR10               GPIO_ANL_AFSELR_ANL_AFSELR10_Msk                
#define GPIO_ANL_AFSELR_ANL_AFSELR11_Pos           (22U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR11_Msk           (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR11_Pos)      /*!< 0x00C00000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR11               GPIO_ANL_AFSELR_ANL_AFSELR11_Msk                
#define GPIO_ANL_AFSELR_ANL_AFSELR12_Pos           (24U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR12_Msk           (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR12_Pos)      /*!< 0x03000000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR12               GPIO_ANL_AFSELR_ANL_AFSELR12_Msk                
#define GPIO_ANL_AFSELR_ANL_AFSELR13_Pos           (26U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR13_Msk           (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR13_Pos)      /*!< 0x0C000000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR13               GPIO_ANL_AFSELR_ANL_AFSELR13_Msk                
#define GPIO_ANL_AFSELR_ANL_AFSELR14_Pos           (28U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR14_Msk           (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR14_Pos)      /*!< 0x30000000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR14               GPIO_ANL_AFSELR_ANL_AFSELR14_Msk                
#define GPIO_ANL_AFSELR_ANL_AFSELR15_Pos           (30U)                                 
#define GPIO_ANL_AFSELR_ANL_AFSELR15_Msk           (0x3U << GPIO_ANL_AFSELR_ANL_AFSELR15_Pos)      /*!< 0xC0000000 */
#define GPIO_ANL_AFSELR_ANL_AFSELR15               GPIO_ANL_AFSELR_ANL_AFSELR15_Msk                

#define GPIO_OUTENSET_OUTENSET0_Pos      (0U)                                  
#define GPIO_OUTENSET_OUTENSET0_Msk      (0x1U << GPIO_OUTENSET_OUTENSET0_Pos) 	/*!< 0x00000001 */
#define GPIO_OUTENSET_OUTENSET0        	 GPIO_OUTENSET_OUTENSET0_Msk                      
#define GPIO_OUTENSET_OUTENSET1_Pos      (1U)                                  
#define GPIO_OUTENSET_OUTENSET1_Msk      (0x1U << GPIO_OUTENSET_OUTENSET1_Pos) 	/*!< 0x00000002 */
#define GPIO_OUTENSET_OUTENSET1        	 GPIO_OUTENSET_OUTENSET1_Msk                      
#define GPIO_OUTENSET_OUTENSET2_Pos      (2U)                                  
#define GPIO_OUTENSET_OUTENSET2_Msk      (0x1U << GPIO_OUTENSET_OUTENSET2_Pos) 	/*!< 0x00000004 */
#define GPIO_OUTENSET_OUTENSET2        	 GPIO_OUTENSET_OUTENSET2_Msk   
#define GPIO_OUTENSET_OUTENSET3_Pos      (3U)                                  
#define GPIO_OUTENSET_OUTENSET3_Msk      (0x1U << GPIO_OUTENSET_OUTENSET3_Pos) 	/*!< 0x00000008 */
#define GPIO_OUTENSET_OUTENSET3        	 GPIO_OUTENSET_OUTENSET3_Msk    
#define GPIO_OUTENSET_OUTENSET4_Pos      (4U)                                  
#define GPIO_OUTENSET_OUTENSET4_Msk      (0x1U << GPIO_OUTENSET_OUTENSET4_Pos) 	/*!< 0x00000010 */
#define GPIO_OUTENSET_OUTENSET4        	 GPIO_OUTENSET_OUTENSET4_Msk    
#define GPIO_OUTENSET_OUTENSET5_Pos      (5U)                                  
#define GPIO_OUTENSET_OUTENSET5_Msk      (0x1U << GPIO_OUTENSET_OUTENSET5_Pos) 	/*!< 0x00000020 */
#define GPIO_OUTENSET_OUTENSET5        	 GPIO_OUTENSET_OUTENSET5_Msk  
#define GPIO_OUTENSET_OUTENSET6_Pos      (6U)                                  
#define GPIO_OUTENSET_OUTENSET6_Msk      (0x1U << GPIO_OUTENSET_OUTENSET6_Pos) 	/*!< 0x00000040 */
#define GPIO_OUTENSET_OUTENSET6        	 GPIO_OUTENSET_OUTENSET6_Msk    
#define GPIO_OUTENSET_OUTENSET7_Pos      (7U)                                  
#define GPIO_OUTENSET_OUTENSET7_Msk      (0x1U << GPIO_OUTENSET_OUTENSET7_Pos) 	/*!< 0x00000080 */
#define GPIO_OUTENSET_OUTENSET7        	 GPIO_OUTENSET_OUTENSET7_Msk    
#define GPIO_OUTENSET_OUTENSET8_Pos      (8U)                                  
#define GPIO_OUTENSET_OUTENSET8_Msk      (0x1U << GPIO_OUTENSET_OUTENSET8_Pos) 	/*!< 0x00000100 */
#define GPIO_OUTENSET_OUTENSET8         	GPIO_OUTENSET_OUTENSET8_Msk    
#define GPIO_OUTENSET_OUTENSET9_Pos      (9U)                                  
#define GPIO_OUTENSET_OUTENSET9_Msk      (0x1U << GPIO_OUTENSET_OUTENSET9_Pos) 	/*!< 0x00000200 */
#define GPIO_OUTENSET_OUTENSET9         	GPIO_OUTENSET_OUTENSET9_Msk    
#define GPIO_OUTENSET_OUTENSET10_Pos     (10U)                                  
#define GPIO_OUTENSET_OUTENSET10_Msk     (0x1U << GPIO_OUTENSET_OUTENSET10_Pos) /*!< 0x00000400 */
#define GPIO_OUTENSET_OUTENSET10       	 GPIO_OUTENSET_OUTENSET10_Msk    
#define GPIO_OUTENSET_OUTENSET11_Pos     (11U)                                  
#define GPIO_OUTENSET_OUTENSET11_Msk     (0x1U << GPIO_OUTENSET_OUTENSET11_Pos) /*!< 0x00000800 */
#define GPIO_OUTENSET_OUTENSET11       	 GPIO_OUTENSET_OUTENSET11_Msk    
#define GPIO_OUTENSET_OUTENSET12_Pos     (12U)                                  
#define GPIO_OUTENSET_OUTENSET12_Msk     (0x1U << GPIO_OUTENSET_OUTENSET12_Pos) /*!< 0x00001000 */
#define GPIO_OUTENSET_OUTENSET12       	 GPIO_OUTENSET_OUTENSET12_Msk    
#define GPIO_OUTENSET_OUTENSET13_Pos     (13U)                                  
#define GPIO_OUTENSET_OUTENSET13_Msk     (0x1U << GPIO_OUTENSET_OUTENSET13_Pos) /*!< 0x00002000 */
#define GPIO_OUTENSET_OUTENSET13       	 GPIO_OUTENSET_OUTENSET13_Msk    
#define GPIO_OUTENSET_OUTENSET14_Pos     (14U)                                  
#define GPIO_OUTENSET_OUTENSET14_Msk     (0x1U << GPIO_OUTENSET_OUTENSET14_Pos) /*!< 0x00004000 */
#define GPIO_OUTENSET_OUTENSET14        	GPIO_OUTENSET_OUTENSET14_Msk    
#define GPIO_OUTENSET_OUTENSET15_Pos     (15U)                                  
#define GPIO_OUTENSET_OUTENSET15_Msk     (0x1U << GPIO_OUTENSET_OUTENSET15_Pos) /*!< 0x00008000 */
#define GPIO_OUTENSET_OUTENSET15        	GPIO_OUTENSET_OUTENSET15_Msk    

#define GPIO_OUTENCLR_OUTENCLR0_Pos      (0U)                                  
#define GPIO_OUTENCLR_OUTENCLR0_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR0_Pos) 	/*!< 0x00000001 */
#define GPIO_OUTENCLR_OUTENCLR0          GPIO_OUTENCLR_OUTENCLR0_Msk                      
#define GPIO_OUTENCLR_OUTENCLR1_Pos      (1U)                                  
#define GPIO_OUTENCLR_OUTENCLR1_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR1_Pos) 	/*!< 0x00000002 */
#define GPIO_OUTENCLR_OUTENCLR1         	GPIO_OUTENCLR_OUTENCLR1_Msk                      
#define GPIO_OUTENCLR_OUTENCLR2_Pos      (2U)                                  
#define GPIO_OUTENCLR_OUTENCLR2_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR2_Pos) 	/*!< 0x00000004 */
#define GPIO_OUTENCLR_OUTENCLR2          GPIO_OUTENCLR_OUTENCLR2_Msk   
#define GPIO_OUTENCLR_OUTENCLR3_Pos      (3U)                                  
#define GPIO_OUTENCLR_OUTENCLR3_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR3_Pos) 	/*!< 0x00000008 */
#define GPIO_OUTENCLR_OUTENCLR3         	GPIO_OUTENCLR_OUTENCLR3_Msk    
#define GPIO_OUTENCLR_OUTENCLR4_Pos      (4U)                                  
#define GPIO_OUTENCLR_OUTENCLR4_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR4_Pos) 	/*!< 0x00000010 */
#define GPIO_OUTENCLR_OUTENCLR4        	 GPIO_OUTENCLR_OUTENCLR4_Msk    
#define GPIO_OUTENCLR_OUTENCLR5_Pos      (5U)                                  
#define GPIO_OUTENCLR_OUTENCLR5_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR5_Pos) 	/*!< 0x00000020 */
#define GPIO_OUTENCLR_OUTENCLR5        	 GPIO_OUTENCLR_OUTENCLR5_Msk  
#define GPIO_OUTENCLR_OUTENCLR6_Pos      (6U)                                  
#define GPIO_OUTENCLR_OUTENCLR6_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR6_Pos) 	/*!< 0x00000040 */
#define GPIO_OUTENCLR_OUTENCLR6          GPIO_OUTENCLR_OUTENCLR6_Msk    
#define GPIO_OUTENCLR_OUTENCLR7_Pos      (7U)                                  
#define GPIO_OUTENCLR_OUTENCLR7_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR7_Pos) 	/*!< 0x00000080 */
#define GPIO_OUTENCLR_OUTENCLR7          GPIO_OUTENCLR_OUTENCLR7_Msk    
#define GPIO_OUTENCLR_OUTENCLR8_Pos      (8U)                                  
#define GPIO_OUTENCLR_OUTENCLR8_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR8_Pos) 	/*!< 0x00000100 */
#define GPIO_OUTENCLR_OUTENCLR8          GPIO_OUTENCLR_OUTENCLR8_Msk    
#define GPIO_OUTENCLR_OUTENCLR9_Pos      (9U)                                  
#define GPIO_OUTENCLR_OUTENCLR9_Msk      (0x1U << GPIO_OUTENCLR_OUTENCLR9_Pos) 	/*!< 0x00000200 */
#define GPIO_OUTENCLR_OUTENCLR9          GPIO_OUTENCLR_OUTENCLR9_Msk    
#define GPIO_OUTENCLR_OUTENCLR10_Pos     (10U)                                  
#define GPIO_OUTENCLR_OUTENCLR10_Msk     (0x1U << GPIO_OUTENCLR_OUTENCLR10_Pos) /*!< 0x00000400 */
#define GPIO_OUTENCLR_OUTENCLR10         GPIO_OUTENCLR_OUTENCLR10_Msk    
#define GPIO_OUTENCLR_OUTENCLR11_Pos     (11U)                                  
#define GPIO_OUTENCLR_OUTENCLR11_Msk     (0x1U << GPIO_OUTENCLR_OUTENCLR11_Pos) /*!< 0x00000800 */
#define GPIO_OUTENCLR_OUTENCLR11         GPIO_OUTENCLR_OUTENCLR11_Msk    
#define GPIO_OUTENCLR_OUTENCLR12_Pos     (12U)                                  
#define GPIO_OUTENCLR_OUTENCLR12_Msk     (0x1U << GPIO_OUTENCLR_OUTENCLR12_Pos) /*!< 0x00001000 */
#define GPIO_OUTENCLR_OUTENCLR12         GPIO_OUTENCLR_OUTENCLR12_Msk    
#define GPIO_OUTENCLR_OUTENCLR13_Pos     (13U)                                  
#define GPIO_OUTENCLR_OUTENCLR13_Msk     (0x1U << GPIO_OUTENCLR_OUTENCLR13_Pos) /*!< 0x00002000 */
#define GPIO_OUTENCLR_OUTENCLR13         GPIO_OUTENCLR_OUTENCLR13_Msk    
#define GPIO_OUTENCLR_OUTENCLR14_Pos     (14U)                                  
#define GPIO_OUTENCLR_OUTENCLR14_Msk     (0x1U << GPIO_OUTENCLR_OUTENCLR14_Pos) /*!< 0x00004000 */
#define GPIO_OUTENCLR_OUTENCLR14         GPIO_OUTENCLR_OUTENCLR14_Msk    
#define GPIO_OUTENCLR_OUTENCLR15_Pos     (15U)                                  
#define GPIO_OUTENCLR_OUTENCLR15_Msk     (0x1U << GPIO_OUTENCLR_OUTENCLR15_Pos) /*!< 0x00008000 */
#define GPIO_OUTENCLR_OUTENCLR15         GPIO_OUTENCLR_OUTENCLR15_Msk    

#define GPIO_OTYPER_OTYPER0_Pos            (0U)                                  
#define GPIO_OTYPER_OTYPER0_Msk            (0x3U << GPIO_OTYPER_OTYPER0_Pos)       /*!< 0x00000003 */
#define GPIO_OTYPER_OTYPER0                GPIO_OTYPER_OTYPER0_Msk                 
#define GPIO_OTYPER_OTYPER1_Pos            (2U)                                  
#define GPIO_OTYPER_OTYPER1_Msk            (0x3U << GPIO_OTYPER_OTYPER1_Pos)       /*!< 0x0000000C */
#define GPIO_OTYPER_OTYPER1                GPIO_OTYPER_OTYPER1_Msk                 
#define GPIO_OTYPER_OTYPER2_Pos            (4U)                                  
#define GPIO_OTYPER_OTYPER2_Msk            (0x3U << GPIO_OTYPER_OTYPER2_Pos)       /*!< 0x00000030 */
#define GPIO_OTYPER_OTYPER2                GPIO_OTYPER_OTYPER2_Msk                 
#define GPIO_OTYPER_OTYPER3_Pos            (6U)                                  
#define GPIO_OTYPER_OTYPER3_Msk            (0x3U << GPIO_OTYPER_OTYPER3_Pos)       /*!< 0x000000C0 */
#define GPIO_OTYPER_OTYPER3                GPIO_OTYPER_OTYPER3_Msk                 
#define GPIO_OTYPER_OTYPER4_Pos            (8U)                                  
#define GPIO_OTYPER_OTYPER4_Msk            (0x3U << GPIO_OTYPER_OTYPER4_Pos)       /*!< 0x00000300 */
#define GPIO_OTYPER_OTYPER4                GPIO_OTYPER_OTYPER4_Msk                 
#define GPIO_OTYPER_OTYPER5_Pos            (10U)                                 
#define GPIO_OTYPER_OTYPER5_Msk            (0x3U << GPIO_OTYPER_OTYPER5_Pos)       /*!< 0x00000C00 */
#define GPIO_OTYPER_OTYPER5                GPIO_OTYPER_OTYPER5_Msk                 
#define GPIO_OTYPER_OTYPER6_Pos            (12U)                                 
#define GPIO_OTYPER_OTYPER6_Msk            (0x3U << GPIO_OTYPER_OTYPER6_Pos)       /*!< 0x00003000 */
#define GPIO_OTYPER_OTYPER6                GPIO_OTYPER_OTYPER6_Msk                 
#define GPIO_OTYPER_OTYPER7_Pos            (14U)                                 
#define GPIO_OTYPER_OTYPER7_Msk            (0x3U << GPIO_OTYPER_OTYPER7_Pos)       /*!< 0x0000C000 */
#define GPIO_OTYPER_OTYPER7                GPIO_POTYPER_OTYPER7_Msk                 
#define GPIO_OTYPER_OTYPER8_Pos            (16U)                                 
#define GPIO_OTYPER_OTYPER8_Msk            (0x3U << GPIO_OTYPER_OTYPER8_Pos)       /*!< 0x00030000 */
#define GPIO_OTYPER_OTYPER8                GPIO_OTYPER_OTYPER8_Msk                 
#define GPIO_OTYPER_OTYPER9_Pos            (18U)                                 
#define GPIO_OTYPER_OTYPER9_Msk            (0x3U << GPIO_OTYPER_OTYPER9_Pos)       /*!< 0x000C0000 */
#define GPIO_OTYPER_OTYPER9                GPIO_OTYPER_OTYPER9_Msk                 
#define GPIO_OTYPER_OTYPER10_Pos           (20U)                                 
#define GPIO_OTYPER_OTYPER10_Msk           (0x3U << GPIO_OTYPER_OTYPER10_Pos)      /*!< 0x00300000 */
#define GPIO_OTYPER_OTYPER10               GPIO_OTYPER_OTYPER10_Msk                
#define GPIO_OTYPER_OTYPER11_Pos           (22U)                                 
#define GPIO_OTYPER_OTYPER11_Msk           (0x3U << GPIO_OTYPER_OTYPER11_Pos)      /*!< 0x00C00000 */
#define GPIO_OTYPER_OTYPER11               GPIO_OTYPER_OTYPER11_Msk                
#define GPIO_OTYPER_OTYPER12_Pos           (24U)                                 
#define GPIO_OTYPER_OTYPER12_Msk           (0x3U << GPIO_OTYPER_OTYPER12_Pos)      /*!< 0x03000000 */
#define GPIO_OTYPER_OTYPER12               GPIO_OTYPER_OTYPER12_Msk                
#define GPIO_OTYPER_OTYPER13_Pos           (26U)                                 
#define GPIO_OTYPER_OTYPER13_Msk           (0x3U << GPIO_OTYPER_OTYPER13_Pos)      /*!< 0x0C000000 */
#define GPIO_OTYPER_OTYPER13               GPIO_OTYPER_OTYPER13_Msk                
#define GPIO_OTYPER_OTYPER14_Pos           (28U)                                 
#define GPIO_OTYPER_OTYPER14_Msk           (0x3U << GPIO_OTYPER_OTYPER14_Pos)      /*!< 0x30000000 */
#define GPIO_OTYPER_OTYPER14               GPIO_OTYPER_OTYPER14_Msk                
#define GPIO_OTYPER_OTYPER15_Pos           (30U)                                 
#define GPIO_OTYPER_OTYPER15_Msk           (0x3U << GPIO_OTYPER_OTYPER15_Pos)      /*!< 0xC0000000 */
#define GPIO_OTYPER_OTYPER15               GPIO_OTYPER_OTYPER15_Msk                

#define GPIO_PUR_PUR0_Pos            (0U)                                  
#define GPIO_PUR_PUR0_Msk            (0x3U << GPIO_PUR_PUR0_Pos)       /*!< 0x00000003 */
#define GPIO_PUR_PUR0                GPIO_PUR_PUR0_Msk                 
#define GPIO_PUR_PUR1_Pos            (2U)                                  
#define GPIO_PUR_PUR1_Msk            (0x3U << GPIO_PUR_PUR1_Pos)       /*!< 0x0000000C */
#define GPIO_PUR_PUR1                GPIO_PUR_PUR1_Msk                 
#define GPIO_PUR_PUR2_Pos            (4U)                                  
#define GPIO_PUR_PUR2_Msk            (0x3U << GPIO_PUR_PUR2_Pos)       /*!< 0x00000030 */
#define GPIO_PUR_PUR2                GPIO_PUR_PUR2_Msk                 
#define GPIO_PUR_PUR3_Pos            (6U)                                  
#define GPIO_PUR_PUR3_Msk            (0x3U << GPIO_PUR_PUR3_Pos)       /*!< 0x000000C0 */
#define GPIO_PUR_PUR3                GPIO_PUR_PUR3_Msk                 
#define GPIO_PUR_PUR4_Pos            (8U)                                  
#define GPIO_PUR_PUR4_Msk            (0x3U << GPIO_PUR_PUR4_Pos)       /*!< 0x00000300 */
#define GPIO_PUR_PUR4                GPIO_PUR_PUR4_Msk                 
#define GPIO_PUR_PUR5_Pos            (10U)                                 
#define GPIO_PUR_PUR5_Msk            (0x3U << GPIO_PUR_PUR5_Pos)       /*!< 0x00000C00 */
#define GPIO_PUR_PUR5                GPIO_PUR_PUR5_Msk                 
#define GPIO_PUR_PUR6_Pos            (12U)                                 
#define GPIO_PUR_PUR6_Msk            (0x3U << GPIO_PUR_PUR6_Pos)       /*!< 0x00003000 */
#define GPIO_PUR_PUR6                GPIO_PUR_PUR6_Msk                 
#define GPIO_PUR_PUR7_Pos            (14U)                                 
#define GPIO_PUR_PUR7_Msk            (0x3U << GPIO_PUR_PUR7_Pos)       /*!< 0x0000C000 */
#define GPIO_PUR_PUR7                GPIO_PUR_PUR7_Msk                 
#define GPIO_PUR_PUR8_Pos            (16U)                                 
#define GPIO_PUR_PUR8_Msk            (0x3U << GPIO_PUR_PUR8_Pos)       /*!< 0x00030000 */
#define GPIO_PUR_PUR8                GPIO_PUR_PUR8_Msk                 
#define GPIO_PUR_PUR9_Pos            (18U)                                 
#define GPIO_PUR_PUR9_Msk            (0x3U << GPIO_PUR_PUR9_Pos)       /*!< 0x000C0000 */
#define GPIO_PUR_PUR9                GPIO_PUR_PUR9_Msk                 
#define GPIO_PUR_PUR10_Pos           (20U)                                 
#define GPIO_PUR_PUR10_Msk           (0x3U << GPIO_PUR_PUR10_Pos)      /*!< 0x00300000 */
#define GPIO_PUR_PUR10               GPIO_PUR_PUR10_Msk                
#define GPIO_PUR_PUR11_Pos           (22U)                                 
#define GPIO_PUR_PUR11_Msk           (0x3U << GPIO_PUR_PUR11_Pos)      /*!< 0x00C00000 */
#define GPIO_PUR_PUR11               GPIO_PUR_PUR11_Msk                
#define GPIO_PUR_PUR12_Pos           (24U)                                 
#define GPIO_PUR_PUR12_Msk           (0x3U << GPIO_PUR_PUR12_Pos)      /*!< 0x03000000 */
#define GPIO_PUR_PUR12               GPIO_PUR_PUR12_Msk                
#define GPIO_PUR_PUR13_Pos           (26U)                                 
#define GPIO_PUR_PUR13_Msk           (0x3U << GPIO_PUR_PUR13_Pos)      /*!< 0x0C000000 */
#define GPIO_PUR_PUR13               GPIO_PUR_PUR13_Msk                
#define GPIO_PUR_PUR14_Pos           (28U)                                 
#define GPIO_PUR_PUR14_Msk           (0x3U << GPIO_PUR_PUR14_Pos)      /*!< 0x30000000 */
#define GPIO_PUR_PUR14               GPIO_PUR_PUR14_Msk                
#define GPIO_PUR_PUR15_Pos           (30U)                                 
#define GPIO_PUR_PUR15_Msk           (0x3U << GPIO_PUR_PUR15_Pos)      /*!< 0xC0000000 */
#define GPIO_PUR_PUR15               GPIO_PUR_PUR15_Msk                

#define GPIO_PDR_PDR0_Pos            (0U)                                  
#define GPIO_PDR_PDR0_Msk            (0x3U << GPIO_PDR_PDR0_Pos)       /*!< 0x00000003 */
#define GPIO_PDR_PDR0                GPIO_PDR_PDR0_Msk                 
#define GPIO_PDR_PDR1_Pos            (2U)                                  
#define GPIO_PDR_PDR1_Msk            (0x3U << GPIO_PDR_PDR1_Pos)       /*!< 0x0000000C */
#define GPIO_PDR_PDR1                GPIO_PDR_PDR1_Msk                 
#define GPIO_PDR_PDR2_Pos            (4U)                                  
#define GPIO_PDR_PDR2_Msk            (0x3U << GPIO_PDR_PDR2_Pos)       /*!< 0x00000030 */
#define GPIO_PDR_PDR2                GPIO_PDR_PDR2_Msk                 
#define GPIO_PDR_PDR3_Pos            (6U)                                  
#define GPIO_PDR_PDR3_Msk            (0x3U << GPIO_PDR_PDR3_Pos)       /*!< 0x000000C0 */
#define GPIO_PDR_PDR3                GPIO_PDR_PDR3_Msk                 
#define GPIO_PDR_PDR4_Pos            (8U)                                  
#define GPIO_PDR_PDR4_Msk            (0x3U << GPIO_PDR_PDR4_Pos)       /*!< 0x00000300 */
#define GPIO_PDR_PDR4                GPIO_PDR_PDR4_Msk                 
#define GPIO_PDR_PDR5_Pos            (10U)                                 
#define GPIO_PDR_PDR5_Msk            (0x3U << GPIO_PDR_PDR5_Pos)       /*!< 0x00000C00 */
#define GPIO_PDR_PDR5                GPIO_PDR_PDR5_Msk                 
#define GPIO_PDR_PDR6_Pos            (12U)                                 
#define GPIO_PDR_PDR6_Msk            (0x3U << GPIO_PDR_PDR6_Pos)       /*!< 0x00003000 */
#define GPIO_PDR_PDR6                GPIO_PDR_PDR6_Msk                 
#define GPIO_PDR_PDR7_Pos            (14U)                                 
#define GPIO_PDR_PDR7_Msk            (0x3U << GPIO_PDR_PDR7_Pos)       /*!< 0x0000C000 */
#define GPIO_PDR_PDR7                GPIO_PDR_PDR7_Msk                 
#define GPIO_PDR_PDR8_Pos            (16U)                                 
#define GPIO_PDR_PDR8_Msk            (0x3U << GPIO_PDR_PDR8_Pos)       /*!< 0x00030000 */
#define GPIO_PDR_PDR8                GPIO_PDR_PDR8_Msk                 
#define GPIO_PDR_PDR9_Pos            (18U)                                 
#define GPIO_PDR_PDR9_Msk            (0x3U << GPIO_PDR_PDR9_Pos)       /*!< 0x000C0000 */
#define GPIO_PDR_PDR9                GPIO_PDR_PDR9_Msk                 
#define GPIO_PDR_PDR10_Pos           (20U)                                 
#define GPIO_PDR_PDR10_Msk           (0x3U << GPIO_PDR_PDR10_Pos)      /*!< 0x00300000 */
#define GPIO_PDR_PDR10               GPIO_PDR_PDR10_Msk                
#define GPIO_PDR_PDR11_Pos           (22U)                                 
#define GPIO_PDR_PDR11_Msk           (0x3U << GPIO_PDR_PDR11_Pos)      /*!< 0x00C00000 */
#define GPIO_PDR_PDR11               GPIO_PDR_PDR11_Msk                
#define GPIO_PDR_PDR12_Pos           (24U)                                 
#define GPIO_PDR_PDR12_Msk           (0x3U << GPIO_PDR_PDR12_Pos)      /*!< 0x03000000 */
#define GPIO_PDR_PDR12               GPIO_PDR_PDR12_Msk                
#define GPIO_PDR_PDR13_Pos           (26U)                                 
#define GPIO_PDR_PDR13_Msk           (0x3U << GPIO_PDR_PDR13_Pos)      /*!< 0x0C000000 */
#define GPIO_PDR_PDR13               GPIO_PDR_PDR13_Msk                
#define GPIO_PDR_PDR14_Pos           (28U)                                 
#define GPIO_PDR_PDR14_Msk           (0x3U << GPIO_PDR_PDR14_Pos)      /*!< 0x30000000 */
#define GPIO_PDR_PDR14               GPIO_PDR_PDR14_Msk                
#define GPIO_PDR_PDR15_Pos           (30U)                                 
#define GPIO_PDR_PDR15_Msk           (0x3U << GPIO_PDR_PDR15_Pos)      /*!< 0xC0000000 */
#define GPIO_PDR_PDR15               GPIO_PDR_PDR15_Msk                

#define GPIO_HDHSR_HDHSR0_Pos      (0U)                                  
#define GPIO_HDHSR_HDHSR0_Msk      (0x1U << GPIO_HDHSR_HDHSR0_Pos) 	/*!< 0x00000001 */
#define GPIO_HDHSR_HDHSR0          GPIO_HDHSR_HDHSR0_Msk                      
#define GPIO_HDHSR_HDHSR1_Pos      (1U)                                  
#define GPIO_HDHSR_HDHSR1_Msk      (0x1U << GPIO_HDHSR_HDHSR1_Pos) 	/*!< 0x00000002 */
#define GPIO_HDHSR_HDHSR1         	GPIO_HDHSR_HDHSR1_Msk                      
#define GPIO_HDHSR_HDHSR2_Pos      (2U)                                  
#define GPIO_HDHSR_HDHSR2_Msk      (0x1U << GPIO_HDHSR_HDHSR2_Pos) 	/*!< 0x00000004 */
#define GPIO_HDHSR_HDHSR2          GPIO_HDHSR_HDHSR2_Msk   
#define GPIO_HDHSR_HDHSR3_Pos      (3U)                                  
#define GPIO_HDHSR_HDHSR3_Msk      (0x1U << GPIO_HDHSR_HDHSR3_Pos) 	/*!< 0x00000008 */
#define GPIO_HDHSR_HDHSR3         	GPIO_HDHSR_HDHSR3_Msk    
#define GPIO_HDHSR_HDHSR4_Pos      (4U)                                  
#define GPIO_HDHSR_HDHSR4_Msk      (0x1U << GPIO_HDHSR_HDHSR4_Pos) 	/*!< 0x00000010 */
#define GPIO_HDHSR_HDHSR4        	 GPIO_HDHSR_HDHSR4_Msk    
#define GPIO_HDHSR_HDHSR5_Pos      (5U)                                  
#define GPIO_HDHSR_HDHSR5_Msk      (0x1U << GPIO_HDHSR_HDHSR5_Pos) 	/*!< 0x00000020 */
#define GPIO_HDHSR_HDHSR5        	 GPIO_HDHSR_HDHSR5_Msk  
#define GPIO_HDHSR_HDHSR6_Pos      (6U)                                  
#define GPIO_HDHSR_HDHSR6_Msk      (0x1U << GPIO_HDHSR_HDHSR6_Pos) 	/*!< 0x00000040 */
#define GPIO_HDHSR_HDHSR6          GPIO_HDHSR_HDHSR6_Msk    
#define GPIO_HDHSR_HDHSR7_Pos      (7U)                                  
#define GPIO_HDHSR_HDHSR7_Msk      (0x1U << GPIO_HDHSR_HDHSR7_Pos) 	/*!< 0x00000080 */
#define GPIO_HDHSR_HDHSR7          GPIO_HDHSR_HDHSR7_Msk    
#define GPIO_HDHSR_HDHSR8_Pos      (8U)                                  
#define GPIO_HDHSR_HDHSR8_Msk      (0x1U << GPIO_HDHSR_HDHSR8_Pos) 	/*!< 0x00000100 */
#define GPIO_HDHSR_HDHSR8          GPIO_HDHSR_HDHSR8_Msk    
#define GPIO_HDHSR_HDHSR9_Pos      (9U)                                  
#define GPIO_HDHSR_HDHSR9_Msk      (0x1U << GPIO_HDHSR_HDHSR9_Pos) 	/*!< 0x00000200 */
#define GPIO_HDHSR_HDHSR9          GPIO_HDHSR_HDHSR9_Msk    
#define GPIO_HDHSR_HDHSR10_Pos     (10U)                                  
#define GPIO_HDHSR_HDHSR10_Msk     (0x1U << GPIO_HDHSR_HDHSR10_Pos) /*!< 0x00000400 */
#define GPIO_HDHSR_HDHSR10         GPIO_HDHSR_HDHSR10_Msk    
#define GPIO_HDHSR_HDHSR11_Pos     (11U)                                  
#define GPIO_HDHSR_HDHSR11_Msk     (0x1U << GPIO_HDHSR_HDHSR11_Pos) /*!< 0x00000800 */
#define GPIO_HDHSR_HDHSR11         GPIO_HDHSR_HDHSR11_Msk    
#define GPIO_HDHSR_HDHSR12_Pos     (12U)                                  
#define GPIO_HDHSR_HDHSR12_Msk     (0x1U << GPIO_HDHSR_HDHSR12_Pos) /*!< 0x00001000 */
#define GPIO_HDHSR_HDHSR12         GPIO_HDHSR_HDHSR12_Msk    
#define GPIO_HDHSR_HDHSR13_Pos     (13U)                                  
#define GPIO_HDHSR_HDHSR13_Msk     (0x1U << GPIO_HDHSR_HDHSR13_Pos) /*!< 0x00002000 */
#define GPIO_HDHSR_HDHSR13         GPIO_HDHSR_HDHSR13_Msk    
#define GPIO_HDHSR_HDHSR14_Pos     (14U)                                  
#define GPIO_HDHSR_HDHSR14_Msk     (0x1U << GPIO_HDHSR_HDHSR14_Pos) /*!< 0x00004000 */
#define GPIO_HDHSR_HDHSR14         GPIO_HDHSR_HDHSR14_Msk    
#define GPIO_HDHSR_HDHSR15_Pos     (15U)                                  
#define GPIO_HDHSR_HDHSR15_Msk     (0x1U << GPIO_HDHSR_HDHSR15_Pos) /*!< 0x00008000 */
#define GPIO_HDHSR_HDHSR15         GPIO_HDHSR_HDHSR15_Msk    

#define GPIO_IHYSTER_IHYSTER0_Pos      (0U)                                  
#define GPIO_IHYSTER_IHYSTER0_Msk      (0x1U << GPIO_IHYSTER_IHYSTER0_Pos) 	/*!< 0x00000001 */
#define GPIO_IHYSTER_IHYSTER0          GPIO_IHYSTER_IHYSTER0_Msk                      
#define GPIO_IHYSTER_IHYSTER1_Pos      (1U)                                  
#define GPIO_IHYSTER_IHYSTER1_Msk      (0x1U << GPIO_IHYSTER_IHYSTER1_Pos) 	/*!< 0x00000002 */
#define GPIO_IHYSTER_IHYSTER1         	GPIO_IHYSTER_IHYSTER1_Msk                      
#define GPIO_IHYSTER_IHYSTER2_Pos      (2U)                                  
#define GPIO_IHYSTER_IHYSTER2_Msk      (0x1U << GPIO_IHYSTER_IHYSTER2_Pos) 	/*!< 0x00000004 */
#define GPIO_IHYSTER_IHYSTER2          GPIO_IHYSTER_IHYSTER2_Msk   
#define GPIO_IHYSTER_IHYSTER3_Pos      (3U)                                  
#define GPIO_IHYSTER_IHYSTER3_Msk      (0x1U << GPIO_IHYSTER_IHYSTER3_Pos) 	/*!< 0x00000008 */
#define GPIO_IHYSTER_IHYSTER3         	GPIO_IHYSTER_IHYSTER3_Msk    
#define GPIO_IHYSTER_IHYSTER4_Pos      (4U)                                  
#define GPIO_IHYSTER_IHYSTER4_Msk      (0x1U << GPIO_IHYSTER_IHYSTER4_Pos) 	/*!< 0x00000010 */
#define GPIO_IHYSTER_IHYSTER4        	 GPIO_IHYSTER_IHYSTER4_Msk    
#define GPIO_IHYSTER_IHYSTER5_Pos      (5U)                                  
#define GPIO_IHYSTER_IHYSTER5_Msk      (0x1U << GPIO_IHYSTER_IHYSTER5_Pos) 	/*!< 0x00000020 */
#define GPIO_IHYSTER_IHYSTER5        	 GPIO_IHYSTER_IHYSTER5_Msk  
#define GPIO_IHYSTER_IHYSTER6_Pos      (6U)                                  
#define GPIO_IHYSTER_IHYSTER6_Msk      (0x1U << GPIO_IHYSTER_IHYSTER6_Pos) 	/*!< 0x00000040 */
#define GPIO_IHYSTER_IHYSTER6          GPIO_IHYSTER_IHYSTER6_Msk    
#define GPIO_IHYSTER_IHYSTER7_Pos      (7U)                                  
#define GPIO_IHYSTER_IHYSTER7_Msk      (0x1U << GPIO_IHYSTER_IHYSTER7_Pos) 	/*!< 0x00000080 */
#define GPIO_IHYSTER_IHYSTER7          GPIO_IHYSTER_IHYSTER7_Msk    
#define GPIO_IHYSTER_IHYSTER8_Pos      (8U)                                  
#define GPIO_IHYSTER_IHYSTER8_Msk      (0x1U << GPIO_IHYSTER_IHYSTER8_Pos) 	/*!< 0x00000100 */
#define GPIO_IHYSTER_IHYSTER8          GPIO_IHYSTER_IHYSTER8_Msk    
#define GPIO_IHYSTER_IHYSTER9_Pos      (9U)                                  
#define GPIO_IHYSTER_IHYSTER9_Msk      (0x1U << GPIO_IHYSTER_IHYSTER9_Pos) 	/*!< 0x00000200 */
#define GPIO_IHYSTER_IHYSTER9          GPIO_IHYSTER_IHYSTER9_Msk    
#define GPIO_IHYSTER_IHYSTER10_Pos     (10U)                                  
#define GPIO_IHYSTER_IHYSTER10_Msk     (0x1U << GPIO_IHYSTER_IHYSTER10_Pos) /*!< 0x00000400 */
#define GPIO_IHYSTER_IHYSTER10         GPIO_IHYSTER_IHYSTER10_Msk    
#define GPIO_IHYSTER_IHYSTER11_Pos     (11U)                                  
#define GPIO_IHYSTER_IHYSTER11_Msk     (0x1U << GPIO_IHYSTER_IHYSTER11_Pos) /*!< 0x00000800 */
#define GPIO_IHYSTER_IHYSTER11         GPIO_IHYSTER_IHYSTER11_Msk    
#define GPIO_IHYSTER_IHYSTER12_Pos     (12U)                                  
#define GPIO_IHYSTER_IHYSTER12_Msk     (0x1U << GPIO_IHYSTER_IHYSTER12_Pos) /*!< 0x00001000 */
#define GPIO_IHYSTER_IHYSTER12         GPIO_IHYSTER_IHYSTER12_Msk    
#define GPIO_IHYSTER_IHYSTER13_Pos     (13U)                                  
#define GPIO_IHYSTER_IHYSTER13_Msk     (0x1U << GPIO_IHYSTER_IHYSTER13_Pos) /*!< 0x00002000 */
#define GPIO_IHYSTER_IHYSTER13         GPIO_IHYSTER_IHYSTER13_Msk    
#define GPIO_IHYSTER_IHYSTER14_Pos     (14U)                                  
#define GPIO_IHYSTER_IHYSTER14_Msk     (0x1U << GPIO_IHYSTER_IHYSTER14_Pos) /*!< 0x00004000 */
#define GPIO_IHYSTER_IHYSTER14         GPIO_IHYSTER_IHYSTER14_Msk    
#define GPIO_IHYSTER_IHYSTER15_Pos     (15U)                                  
#define GPIO_IHYSTER_IHYSTER15_Msk     (0x1U << GPIO_IHYSTER_IHYSTER15_Pos) /*!< 0x00008000 */
#define GPIO_IHYSTER_IHYSTER15         GPIO_IHYSTER_IHYSTER15_Msk    

/* ================================================================================ */
/* ================            			Flash Control              		 ================ */
/* ================================================================================ */
typedef struct
{
  __IO  uint32_t FLASH_IAPKEY;            /* Offset: 0x000 (R/W)  Flash IAP key */
  __IO 	uint32_t FLASH_IAP_CR0;           /* Offset: 0x004 (R/W)  Flash IAP Control register 0 */
  __IO 	uint32_t FLASH_IAP_CR1;           /* Offset: 0x008 (R/W)  Flash IAP Control register 1 */
  __IO 	uint32_t FLASH_IAP_CR2;           /* Offset: 0x00C (R/W)  Flash IAP Control register 2 */	
  __IO 	uint32_t FLASH_IAP_CR3;           /* Offset: 0x010 (R/W)  Flash IAP Control register 3 */	
				uint32_t RESERVED0[3];	
  __IO 	uint32_t FLASH_PDKEYR;            /* Offset: 0x020 (R/W)  Flash power down control */		
  __IO 	uint32_t FLASH_PD_CSR;            /* Offset: 0x024 (R/W)  Flash power down key */		
				uint32_t RESERVED1[2];		
  __I 	uint32_t CHIPPT;            			/* Offset: 0x030 (R/ )  Chip protect */	
  __I 	uint32_t FRDP1;            				/* Offset: 0x034 (R/ )  Flash read protect 1 */			
  __I 	uint32_t FRDP2;            				/* Offset: 0x038 (R/ )  Flash read protect 2 */			
  __I 	uint32_t FWRP1;            				/* Offset: 0x03C (R/ )  Flash write protect 1 */		
  __I 	uint32_t FWRP2;            				/* Offset: 0x040 (R/ )  Flash write protect 2 */		
	
} FLASHCTRL_TypeDef;
#define FLASHCTRL               ((FLASHCTRL_TypeDef *)  FLASHCTRL_BASE)

/* ================================================================================ */
/* ================          System and power configuration        ================ */
/* ================================================================================ */
typedef struct
{
  __IO  uint32_t SYSCFG_CFGR;            	/* Offset: 0x000 (R/W)  Memory mapping selection */
  __IO 	uint32_t SYSCFG_PWR_CR;           /* Offset: 0x004 (R/W)  System power contorl register */
  __IO 	uint32_t SYSCFG_PWR_CSR;          /* Offset: 0x008 (R/W)  System power contorl and state register */
  __I 	uint32_t SYSHOLD_CSR;           	/* Offset: 0x00C (R/ )  System hold contrl and state register */	
  __IO 	uint32_t SYSCFG_PCFGR;           	/* Offset: 0x010 (R/W)  Peripherals configuration register */		
	
} SYSCFG_TypeDef;
#define SYSCFG               		((SYSCFG_TypeDef *)  SYSCFG_BASE)

/* ================================================================================ */
/* ================            	Clock configuration                ================ */
/* ================================================================================ */
typedef struct
{
  __IO  uint32_t CLK_CFGR0;            		/* Offset: 0x000 (R/W)  Clock configuration register 0 */
  __IO 	uint32_t CLK_CFGR1;           		/* Offset: 0x004 (R/W)  Clock configuration register 1 */
  __IO 	uint32_t CLK_CFGR2;          			/* Offset: 0x008 (R/W)  Clock configuration register 2 */
				uint32_t RESERVED0[5];		
  __IO 	uint32_t CLK_OUT_CR;           		/* Offset: 0x020 (R/ )  Clock output control register */	
				uint32_t RESERVED1[3];		
  __IO 	uint32_t CLK_GATE_KEY;           	/* Offset: 0x030 (R/W)  Clock gating key */		
  __IO 	uint32_t CLK_GATE_CR0;           	/* Offset: 0x034 (R/W)  Clock gagting control register 0 */		
  __IO 	uint32_t CLK_GATE_CR1;           	/* Offset: 0x038 (R/W)  Clock gagting control register 1 */	
  __IO 	uint32_t CLK_GATE_CR2;           	/* Offset: 0x03C (R/W)  Clock gagting control register 2 */		
				uint32_t RESERVED2[7];	
  __IO 	uint32_t CLK_GATE_VFREG_CR;       /* Offset: 0x05C (R/W)  VERIFYSET register clock gating control */			
				uint32_t CLK_PP_CR;								/* Offset: 0x060 (R/W)  Timer1/2 clock control register */
				uint32_t RESERVED4[11];		
  __IO 	uint32_t CLK_CALIB_KEY;       		/* Offset: 0x090 (R/W)  HIRC calibration key */	
  __IO 	uint32_t CLK_CALIB_HIRC;       		/* Offset: 0x094 (R/W)  HIRC calibration control register */				
	
} CLKCFG_TypeDef;
#define CLKCFG               		((CLKCFG_TypeDef *)  CLKCFG_BASE)

/* ================================================================================ */
/* ================                 Reset control                  ================ */
/* ================================================================================ */
typedef struct
{
  __IO  uint32_t RST_SYS_CR;            	/* Offset: 0x000 (R/W)  Software reset control */
  __IO 	uint32_t RST_SYS_CSR;           	/* Offset: 0x004 (R/W)  Reset state register */
  __IO 	uint32_t RST_COMM_CR;          		/* Offset: 0x008 (R/W)  Communication reset control */	
	
} RSTREG_TypeDef;
#define RSTREG               		((RSTREG_TypeDef *)  RSTREG_BASE)

/* ================================================================================ */
/* ================            					PWM          							 ================ */
/* ================================================================================ */
typedef struct
{
				uint32_t RESERVED0[1];		
	__IO  uint32_t PWMENCR;            		/* Offset: 0x004 (R/W)  PWM Enable Register */
				uint32_t RESERVED1[62];		
  __IO 	uint32_t PWM1CR;           			/* Offset: 0x100 (R/W)  PWM1 Control Register */
  __IO 	uint32_t PRD1;          				/* Offset: 0x104 (R/W)  PWM1 Period Register*/
	__IO	uint32_t DT1;										/* Offset: 0x108 (R/W)  PWM1 Duty Register */
  __IO 	uint32_t TMR1;           				/* Offset: 0x10C (R/W)  PWM1 Timer Register */	
				uint32_t RESERVED2[60];		
  __IO 	uint32_t PWM2CR;           			/* Offset: 0x200 (R/W)  PWM2 Control Register */		
  __IO 	uint32_t PRD2;           				/* Offset: 0x204 (R/W)  PWM2 Period Register */		
  __IO 	uint32_t DT2;           				/* Offset: 0x208 (R/W)  PWM2 Duty Register */	
  __IO 	uint32_t TMR2;           				/* Offset: 0x20C (R/W)  PWM2 Timer Register */		
				uint32_t RESERVED3[60];	
  __IO 	uint32_t PWM3CR;       					/* Offset: 0x300 (R/W)  PWM3 Control Register */			
	__IO 	uint32_t PRD3;									/* Offset: 0x304 (R/W)  PWM3 Period Register */
	__IO 	uint32_t DT3;										/* Offset: 0x308 (R/W)  PWM3 Duty Register */
  __IO 	uint32_t TMR3;       						/* Offset: 0x30C (R/W)  PWM3 Timer Register  */		
} PWM_TypeDef;

typedef struct
{
  __IO  uint32_t PWMxCR;            		/* Offset: 0x00 (R/W)  PWM Control Register */
  __IO 	uint32_t PRD;          					/* Offset: 0x04 (R/W)  PWM Period Register*/
	__IO	uint32_t DT;										/* Offset: 0x08 (R/W)  PWM Duty Register */
  __IO 	uint32_t TMR;           				/* Offset: 0x0C (R/W)  PWM Timer Register */	
} single_PWM_TypeDef;

#define PWM               	((PWM_TypeDef *)  PWM_BASE)
#define PWM1                ((single_PWM_TypeDef *) PWM1_BASE)
#define PWM2                ((single_PWM_TypeDef *) PWM2_BASE)
#define PWM3                ((single_PWM_TypeDef *) PWM3_BASE)




/* ================================================================================ */
/* ================            					Timer          						 ================ */
/* ================================================================================ */
typedef struct
{	
	__IO  uint32_t CTRL;            			/* Offset: 0x000 (R/W)  Timer control register */
  __IO 	uint32_t VALUE;           			/* Offset: 0x004 (R/W)  Timer Current value */
  __IO 	uint32_t PRELOAD;          			/* Offset: 0x008 (R/W)  Timer Reload value.*/
	__IO	uint32_t INTSTATUS;							/* Offset: 0x00C (R/W)  Timer interrupt*/
} ARM_TIMER_TypeDef;
#define TM1              	((ARM_TIMER_TypeDef *)  TIMER1_BASE)
#define TM2              	((ARM_TIMER_TypeDef *)  TIMER2_BASE)



/* ================================================================================ */
/* ================            				   UART											 ================ */
/* ================================================================================ */

typedef struct
{	
	__IO  uint32_t DATA;            			/* Offset: 0x000 (R/W)  UART Data value.*/
  __IO 	uint32_t STATE;           			/* Offset: 0x004 (R/W)  UART STATE*/
  __IO 	uint32_t CTRL;          				/* Offset: 0x008 (R/W)  UART control register*/
	__IO	uint32_t INTSTATUS;							/* Offset: 0x00C (R/W)  UART interrupt*/
	__IO	uint32_t BAUDDIV;								/* Offset: 0x010 (R/W)  UART Baud rate divider.*/	
} UART_TypeDef;
#define UART            	((UART_TypeDef *)  UART_BASE)



/* ================================================================================ */
/* ================            				   USART										 ================ */
/* ================================================================================ */

typedef struct
{	
	__IO  uint32_t USARTCR1;            	/* Offset: 0x000 (R/W)  USART control register*/
  __IO 	uint32_t USARTCR2;           		/* Offset: 0x004 (R/W)  USART control register 2 */
  __IO 	uint32_t USARTSR;          			/* Offset: 0x008 (R/W)  USART status register*/
	__IO	uint32_t USARTTD;								/* Offset: 0x00C (R/W)  USART transmit data buffer register */
  __IO 	uint32_t USARTRD;          			/* Offset: 0x010 (R/ )  USART receive data buffer register */
	__IO	uint32_t USARTBR;								/* Offset: 0x014 (R/W)  USART baud rate register */	
} USART_TypeDef;
#define USART            	((USART_TypeDef *)  USART_BASE)


/* ================================================================================ */
/* ================            				   EINT											 ================ */
/* ================================================================================ */
typedef struct
{	
	__IO  uint32_t EINT_FLAG;            	/* Offset: 0x000 (R/W)  External Interrupt Flag register*/
  __IO 	uint32_t EINT_ENCR;           	/* Offset: 0x004 (R/W)  EINT Enable control register 2 */
  __IO 	uint32_t EIESCR;          			/* Offset: 0x008 (R/W)  External Interrupt Edge Select Control Register*/
} EINT_TypeDef;
#define EINT            	((EINT_TypeDef *)  EINT_BASE)

/* ================================================================================ */
/* ================            				   IWDG											 ================ */
/* ================================================================================ */
typedef struct
{	
	__IO  uint32_t WDOGLOAD;            	/* Offset: 0x000 (R/W)  The WDOGLOAD Register contains the value from which */
  __IO 	uint32_t WDOGVALUE;           	/* Offset: 0x004 (R/W)  The WDOGVALUE Register gives the current value of the decrementing counter */
  __IO 	uint32_t WDOGCONTROL;          	/* Offset: 0x008 (R/W)  Watchdog Control Register */
  __O 	uint32_t WDOGINTCLR;          	/* Offset: 0x00C ( /W)  Watchdog Clear Interrupt Register */	
  __IO 	uint32_t WDOGRIS;          			/* Offset: 0x010 (R/W)  Watchdog Raw Interrupt Status Register */	
  __IO 	uint32_t WDOGMIS;          			/* Offset: 0x014 (R/W)  Watchdog Interrupt Status Register */		
  __IO 	uint32_t WDOGLOCK;          		/* Offset: 0xC00 (R/W)  Watchdog Lock Register */			
} IWDG_TypeDef;
#define IWDG            	((IWDG_TypeDef *)  IWDG_BASE)


/* ================================================================================ */
/* ================            				   HLVD											 ================ */
/* ================================================================================ */
typedef struct
{	
	__IO  uint32_t HLVDCR;            	/* Offset: 0x000 (R/W) High / Low Voltage Detector Control Register*/		
} HLVD_TypeDef;
#define HLVD            	((HLVD_TypeDef *)  AIP_BASE)


/* ================================================================================ */
/* ================            				   LVR											 ================ */
/* ================================================================================ */
typedef struct
{	
	__IO  uint32_t LVRCR;            	/* Offset: 0x004 (R/W) Low Voltage Reset Control Register*/		
} LVR_TypeDef;
#define LVR            	((LVR_TypeDef *)  AIP_BASE + 0x04)


/* ================================================================================ */
/* ================            	   1.8V Regulator									 ================ */
/* ================================================================================ */
typedef struct
{	
	__IO  uint32_t V18_KEY;           /* Offset: 0x008 (R/W) 1.8V Regulator KEY*/	
	__IO  uint32_t V18CR;            	/* Offset: 0x00C (R/W) 1.8V Regulator Control Register */		
} V18_TypeDef;
#define V18           	((V18_TypeDef *)  AIP_BASE + 0x08)


/* ================================================================================ */
/* ================            				    TK										   ================ */
/* ================================================================================ */
typedef struct
{	
	__IO  uint32_t TKPC;            	/* Offset: 0x000 (R/W)  Touch Key Pin Control Register */
  __IO 	uint32_t TKCPC;           	/* Offset: 0x004 (R/W)  Touch Key Combine Pin Control Register */
  __IO 	uint32_t TKDCR;          		/* Offset: 0x008 (R/W)  Touch Key Drive Control Register */
	__IO  uint32_t TKSSR;            	/* Offset: 0x00C (R/W)  Touch Key Start & Status Register */
  __IO 	uint32_t TKCR;           		/* Offset: 0x010 (R/W)  Touch Key Control Register */
  __IO 	uint32_t TKCCR;          		/* Offset: 0x014 (R/W)  Touch Key Calculate Cycle Register */
	__IO  uint32_t TKPH1SR;           /* Offset: 0x018 (R/W)  Touch Key Phase1 Width set Register */
  __IO 	uint32_t TKNOSR;           	/* Offset: 0x01C (R/W)  ETouch Key Phase1,2 Non-Overlap Width set Register */
  __IO 	uint32_t TKPH2SR;          	/* Offset: 0x020 (R/W)  Touch Key Phase2 Width set Register */
	__IO  uint32_t TKSWR;            	/* Offset: 0x024 (R/W)  Touch Key Sensing Window Register(PH3) */
        uint32_t RESERVED0[2];
	__IO  uint32_t TKSCR;            	/* Offset: 0x030 (R/W)  Touch Key idle Scan Control Register */
  __IO 	uint32_t TKITOR;           	/* Offset: 0x034 (R/W)  Touch Key idle scan time out counter Register */
  __IO 	uint32_t NISR;          		/* Offset: 0x038 (R/ )  Number of idle scan Register */
        uint32_t RESERVED1[4];
  __IO 	uint32_t SNCR;           		/* Offset: 0x04C (R/W)  EINT Enable control register 2 */
				uint32_t RESERVED2[44];		
	__IO  uint32_t TK1SCR;            /* Offset: 0x100 (R/W)  Touch Key Group 1 Select Control Register */
  __IO 	uint32_t TK1KCR;           	/* Offset: 0x104 (R/W)  Touch Key Group 1 Loading Capacitor Calibration Control Register */
  __IO 	uint32_t TK1CSGCR;          /* Offset: 0x108 (R/W)  Touch Key Group 1 Calculate Step & Gain Control Register */
        uint32_t RESERVED3[1];	
  __IO 	uint32_t TK1B;           		/* Offset: 0x110 (R/W)  The Most Significant Byte of Group 1 Touch Key Buffer */
  __IO 	uint32_t TK1WB;          		/* Offset: 0x114 (R/W)  TK of Group 1 idle Scan Wakeup Base Register */
	__IO  uint32_t TK1WR;           	/* Offset: 0x118 (R/W)  TK of Group 1 idle Scan Wakeup Range Register */
				uint32_t RESERVED4[57];	
				
	__IO  uint32_t TK2SCR;            /* Offset: 0x200 (R/W)  Touch Key Group 2 Select Control Register */
  __IO 	uint32_t TK2KCR;           	/* Offset: 0x204 (R/W)  Touch Key Group 2 Loading Capacitor Calibration Control Register */
  __IO 	uint32_t TK2CSGCR;          /* Offset: 0x208 (R/W)  Touch Key Group 2 Calculate Step & Gain Control Register */
	      uint32_t RESERVED5[1];
  __IO 	uint32_t TK2B;           		/* Offset: 0x210 (R/W)  The Most Significant Byte of Group 2 Touch Key Buffer */
  __IO 	uint32_t TK2WB;          		/* Offset: 0x214 (R/W)  TK of Group 2 idle Scan Wakeup Base Register */
	__IO  uint32_t TK2WR;           	/* Offset: 0x218 (R/W)  TK of Group 2 idle Scan Wakeup Range Register */
				uint32_t RESERVED6[57];
				
	__IO  uint32_t TK3SCR;            /* Offset: 0x300 (R/W)  Touch Key Group 3 Select Control Register */
  __IO 	uint32_t TK3KCR;           	/* Offset: 0x304 (R/W)  Touch Key Group 3 Loading Capacitor Calibration Control Register */
  __IO 	uint32_t TK3CSGCR;          /* Offset: 0x308 (R/W)  Touch Key Group 3 Calculate Step & Gain Control Register */
	      uint32_t RESERVED7[1];
  __IO 	uint32_t TK3B;           		/* Offset: 0x310 (R/W)  The Most Significant Byte of Group 3 Touch Key Buffer */
  __IO 	uint32_t TK3WB;          		/* Offset: 0x314 (R/W)  TK of Group 3 idle Scan Wakeup Base Register */
	__IO  uint32_t TK3WR;           	/* Offset: 0x318 (R/W)  TK of Group 3 idle Scan Wakeup Range Register */
				uint32_t RESERVED8[57];
	
	__IO  uint32_t TK4SCR;            /* Offset: 0x400 (R/W)  Touch Key Group 4 Select Control Register */
  __IO 	uint32_t TK4KCR;           	/* Offset: 0x404 (R/W)  Touch Key Group 4 Loading Capacitor Calibration Control Register */
  __IO 	uint32_t TK4CSGCR;          /* Offset: 0x408 (R/W)  Touch Key Group 4 Calculate Step & Gain Control Register */
	      uint32_t RESERVED9[1];
  __IO 	uint32_t TK4B;           		/* Offset: 0x410 (R/W)  The Most Significant Byte of Group 4 Touch Key Buffer */
  __IO 	uint32_t TK4WB;          		/* Offset: 0x414 (R/W)  TK of Group 4 idle Scan Wakeup Base Register */
	__IO  uint32_t TK4WR;           	/* Offset: 0x418 (R/W)  TK of Group 4 idle Scan Wakeup Range Register */ 
				uint32_t RESERVED10[57];

	__IO  uint32_t TK5SCR;            /* Offset: 0x500 (R/W)  Touch Key Group 5 Select Control Register */
  __IO 	uint32_t TK5KCR;           	/* Offset: 0x504 (R/W)  Touch Key Group 5 Loading Capacitor Calibration Control Register */
  __IO 	uint32_t TK5CSGCR;          /* Offset: 0x508 (R/W)  Touch Key Group 5 Calculate Step & Gain Control Register */
	      uint32_t RESERVED11[1];
  __IO 	uint32_t TK5B;           		/* Offset: 0x510 (R/W)  The Most Significant Byte of Group 5 Touch Key Buffer */
  __IO 	uint32_t TK5WB;          		/* Offset: 0x514 (R/W)  TK of Group 5 idle Scan Wakeup Base Register */
	__IO  uint32_t TK5WR;           	/* Offset: 0x518 (R/W)  TK of Group 5 idle Scan Wakeup Range Register */

				uint32_t RESERVED12[57];
				
	__IO  uint32_t TK6SCR;            /* Offset: 0x600 (R/W)  Touch Key Group 6 Select Control Register */
  __IO 	uint32_t TK6KCR;           	/* Offset: 0x604 (R/W)  Touch Key Group 6 Loading Capacitor Calibration Control Register */
  __IO 	uint32_t TK6CSGCR;          /* Offset: 0x608 (R/W)  Touch Key Group 6 Calculate Step & Gain Control Register */
	      uint32_t RESERVED13[1];
  __IO 	uint32_t TK6B;           		/* Offset: 0x610 (R/W)  The Most Significant Byte of Group 6 Touch Key Buffer */
  __IO 	uint32_t TK6WB;          		/* Offset: 0x614 (R/W)  TK of Group 6 idle Scan Wakeup Base Register */
	__IO  uint32_t TK6WR;           	/* Offset: 0x618 (R/W)  TK of Group 6 idle Scan Wakeup Range Register */

} TK_TypeDef;
#define TK            	((TK_TypeDef *)  TK_BASE)




typedef struct
{	
	__IO  uint32_t TKxSCR;            /* Offset: 0x000 (R/W)  Touch Key Group x Select Control Register */
  __IO 	uint32_t TKxKCR;           	/* Offset: 0x004 (R/W)  Touch Key Group x Loading Capacitor Calibration Control Register */
  __IO 	uint32_t TKxCSGCR;          /* Offset: 0x008 (R/W)  Touch Key of Group x Calculate Step & Gain Control Register */
 				uint32_t RESERVED0[1];	
  __IO 	uint32_t TKxB;           		/* Offset: 0x010 (R/W)  The Most Significant Byte of x Group Touch Key Buffer */
  __IO 	uint32_t TKxWB;          		/* Offset: 0x014 (R/W)  TK of Group x idle Scan Wakeup Base Register */
	__IO  uint32_t TKxWR;           	/* Offset: 0x018 (R/W)  TK of Group x idle Scan Wakeup Range Register */
 
} TK_Groupx_TypeDef;

#define TKG1            	((TK_Groupx_TypeDef *)  TK_Group1_BASE)
#define TKG2            	((TK_Groupx_TypeDef *)  TK_Group2_BASE)
#define TKG3            	((TK_Groupx_TypeDef *)  TK_Group3_BASE)
#define TKG4            	((TK_Groupx_TypeDef *)  TK_Group4_BASE)
#define TKG5            	((TK_Groupx_TypeDef *)  TK_Group5_BASE)
#define TKG6            	((TK_Groupx_TypeDef *)  TK_Group6_BASE)



/* ================================================================================ */
/* ================            				    I2C										   ================ */
/* ================================================================================ */

typedef struct
{	
	__IO  uint32_t I2CON;            	/* Offset: 0x000 (R/W)  I2C control register */
  __IO 	uint32_t I2CSAR;           	/* Offset: 0x004 (R/W)  I2C slave address register */
  __IO 	uint32_t I2CDAR0;          	/* Offset: 0x008 (R/W)  I2C device address register0 */
	__IO  uint32_t I2CBUF;            /* Offset: 0x00C (R/W)  I2C Data Buffer Register */
  __IO 	uint32_t I2CSTA;           	/* Offset: 0x010 (R/W)  I2C start/stop timing register */
  __IO 	uint32_t I2CSDA_FILTER;     /* Offset: 0x014 (R/W)  I2C SDA digital filter */
	__IO  uint32_t I2CTXLEN;          /* Offset: 0x018 (R/W)  I2C transmit buffer length */
  __IO 	uint32_t I2CRXLEN;          /* Offset: 0x01C (R/W)  I2C receive buffer length */
  __IO 	uint32_t I2CRX_NACK;        /* Offset: 0x020 (R/W)  I2C received data number for Non-ack response */
	__IO  uint32_t SMbusTO1;          /* Offset: 0x024 (R/W)  SMbus Time Out 1 register */
  __IO 	uint32_t SMbusTO2;          /* Offset: 0x028 (R/W)  SMbus Time Out 2 register */
  __IO 	uint32_t SMbusTO3;          /* Offset: 0x02C (R/W)  SMbus Time Out 3 register */
	__IO  uint32_t I2CHSCON;          /* Offset: 0x030 (R/W)  I2C high speed mode control register */
  __IO 	uint32_t I2CDIVCNT;         /* Offset: 0x034 (R/W)  I2C Dive count  */
				uint32_t RESERVED[1];      
	__IO  uint32_t I2CDEGLDEL;        /* Offset: 0x03C (R/W)  I2C Deglitch & Delay control register */
  __IO 	uint32_t I2CTXLEN20;        /* Offset: 0x040 (R/W)  I2C transmit buffer length */
  __IO 	uint32_t I2CRXLEN20;        /* Offset: 0x044 (R/W)  I2C receive buffer length */
	__IO  uint32_t I2CRXNACK20;       /* Offset: 0x048 (R/W)  I2C received data number for Non-ack response */

} I2C_TypeDef;
#define I2C            	((I2C_TypeDef *)  I2C_BASE)


/** @addtogroup Exported_macro
  * @{
  */
#define SET_BIT(REG, BIT)     ((REG) |= (BIT))

#define CLEAR_BIT(REG, BIT)   ((REG) &= ~(BIT))

#define READ_BIT(REG, BIT)    ((REG) & (BIT))

#define CLEAR_REG(REG)        ((REG) = (0x0))

#define WRITE_REG(REG, VAL)   ((REG) = (VAL))

#define READ_REG(REG)         ((REG))


#endif
