// ******************************************************************************/
// * @file     option.c
// * @brief    Code Option configuration
// *           
// * @version  V1.05
// * @date     07. May 2021
// ******************************************************************************/

#include <option_def.h>

// <<< Use Configuration Wizard in Context Menu >>>

//------------------------------------------------
//	<h> General Option Configuration
//------------------------------------------------
//		<h> Option1
// 			<o.8> 		IRCPSS				<0=> System Regulator
//															<1=> HIRC internal regulator

// 			<o.0..1> 	HIRC_FREQ_SEL	<0=> 32MHz
//															<1=> 24MHz
//															<2=> 20MHz
//															<3=> 16MHz
//		</h>
			const unsigned int Option1 __attribute__((section(".ARM.__at_0x1FFFEC00")))	= 0xFFFFFEFF;
					
//		<h> Option2
// 			<o.24..25> 	CLK_SWHOLDT	<0=> 31 clock
//															<1=> 15 clock
//															<2=> 7 clock
//															<3=> 3 clock

// 			<o.16> 		ENWDT					<0=> Disable
//															<1=> Enable

// 			<o.8> 		EFTIM					<0=> Pass ~ 10MHz (heavy LPS)
//															<1=> Pass ~ 25MHz (light LPS)

// 			<o.2> 		SHEN					<0=> Disable
//															<1=> Enable

// 			<o.0..1> 	SHCLK					<0=> 16 clock
//															<1=> 8 clock
//															<2=> 2 clock
//															<3=> 4 clock
//		</h>
			const unsigned int Option2 __attribute__((section(".ARM.__at_0x1FFFEC04")))	= 0xFFFFFFFF;
	
//		<h> Option3
// 			<o.7> 		LVREN					<0=> Enable
//															<1=> Disable

// 			<o.0..1> 	LVR						<0=> 4.4V/4.6V
//															<1=> 4.4V/4.6V
//															<2=> 3.6V/3.8V
//															<3=> 2.4V/2.6V
//		</h>
			const unsigned int Option3 __attribute__((section(".ARM.__at_0x1FFFEC08")))	= 0xFFFFFFFF;

// 		<h> SYSOPT_CFGR	
// 			<o.0> 		PC5_En				<0=> Enable
//															<1=> Disable
//		</h>
			const unsigned int SYSOPT_CFGR __attribute__((section(".ARM.__at_0x1FFFEC3C")))	= 0xFFFFFFFF;
			
// 		<h> SYSCFG_CFGR	
// 			<o.0..2> 	REMAP_MODER		<0=> I/D RAM mapped at 0x0000 0000
//															<1=> Boot Code + Main Flash memory + I/D RAM mapped at 0x0000 0000
//															<7=> Main Flash memory mapped at 0x0000 0000
//		</h>
			const unsigned int SYSCFG_CFGR __attribute__((section(".ARM.__at_0x1FFFEC40")))	= 0xFFFFFFFF;
			
//	</h>

//------------------------------------------------
//	<h> Special Option Configuration	
//------------------------------------------------
// 		<h> FRDP1
// 			<o.31> 			FRDP1_EN		<0=> Enable
//															<1=> Disable
// 			<o.16..20> 	FRDP1_SEC		<0x0-0x1F>	
// 			<o.0..15> 	FRDP1_START	<0x0-0xFFFF>	
//		</h>		
			const unsigned int FRDP1 __attribute__((section(".ARM.__at_0x1FFFEC80")))	= 0xFFFFFFFF;
		
// 		<h> FRDP2	
// 			<o.31> 			FRDP2_EN		<0=> Enable
//															<1=> Disable
// 			<o.16..20> 	FRDP2_SEC		<0x0-0x1F>	
// 			<o.0..15> 	FRDP2_START	<0x0-0xFFFF>	
//		</h>		
			const unsigned int FRDP2 __attribute__((section(".ARM.__at_0x1FFFEC84")))	= 0xFFFFFFFF;
			
// 		<h> FWRP1	
// 			<o.31> 			FWRP1_EN		<0=> Enable
//															<1=> Disable
// 			<o.16..20> 	FWRP1_SEC		<0x0-0x1F>	
// 			<o.0..15> 	FWRP1_START	<0x0-0xFFFF>	
//		</h>
			const unsigned int FWRP1 __attribute__((section(".ARM.__at_0x1FFFEC88")))	= 0xFFFFFFFF;			
			
// 		<h> FWRP2	
// 			<o.31> 			FWRP2_EN		<0=> Enable
//															<1=> Disable
// 			<o.16..20> 	FWRP2_SEC		<0x0-0x1F>	
// 			<o.0..15> 	FWRP2_START	<0x0-0xFFFF>	
//		</h>		
			const unsigned int FWRP2 __attribute__((section(".ARM.__at_0x1FFFEC8C")))	= 0xFFFFFFFF;					
			
//    <o> CHIPPT	<0xFFFFFF55=> Protect Disable
//								<0xFFFFFFFF=> Protect Enable
//								<0xFFFFFF77=> Protect Enable	
			const unsigned int CHIPPT __attribute__((section(".ARM.__at_0x1FFFECFC")))	= 0xFFFFFF55;						

//	</h>

// <<< end of configuration section >>>
